<?php
/** Ganda (Luganda)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Kizito
 */

$messages = array(
# User preference toggles
'tog-underline'               => 'Enyunzi ebengako olukoloboze?',
'tog-highlightbroken'         => 'Enyunzi ezigeza okugukka ku mpapula ezitaliwo <a href="" class="new">zifaanane bwezityi</a> (oba bwezityi: <a href="" class="internal">?</a>)',
'tog-justify'                 => "Ennyiriri z'enkanankanye",
'tog-hideminor'               => 'Kisa nkyukakyuka entono ezakakolebwa',
'tog-hidepatrolled'           => "Kisa nkyukakyuka ezakakolebwa ezimaz'okulawunibwa",
'tog-newpageshidepatrolled'   => "Mu lukalala olw'empapula mpya tolaga ezimaz'okulawunibwa",
'tog-extendwatchlist'         => "Olukalala lw'empapula zengoberera lulabike mu bujjuvu, nga ebikyuse byonna mwebiri so ssi ebisinga obugya byokka",
'tog-usenewrc'                => "Olukalala olw'ebikyuse lweyambise obusobozi obw'enyongeza (kyetaagisa 'JavaScript')",
'tog-numberheadings'          => "Emitwe gy'emiko ku mpapula gibengako ennamba",
'tog-showtoolbar'             => "Amapeesa g'ebiyamba mu kuwandika galabikenga (kino kyetaagisa JavaScript)",
'tog-editondblclick'          => "Okunyiga eppeesa emirundi ebiri kubikkulenga w'okyusiza olupapula  (kyetaagisa 'JavaScript')",
'tog-editsection'             => "Emiko ku mpapula gibengako enyunzi eza '[kyusa]' ezikuggusa w'osobolera okugikyusiza.",
'tog-editsectiononrightclick' => "Okunyiga ku omutwe gw'omuko ku lupapula n'eppeesa erya ddyo kubikkulenga w'ogukyusiza (kyetaagisa 'JavaScript')",
'tog-showtoc'                 => 'Teekawo endagiriro (singa ku lupapula kubaako emitwe gisukka mu esatu)',
'tog-rememberpassword'        => 'Ekigambo kyange ekikuumi kitereke ku kompyuta eno',
'tog-watchcreations'          => "Empapula zenkolawo ziteekebwenga ku lukalala lw'ezo zengoberera",
'tog-watchdefault'            => "Empapula zenkyusamu ziteekebwenga ku lukalala lw'ezo zengoberera",
'tog-watchmoves'              => "Empapula zenkyusa erinnya ziteekebwenga ku lukalala lw'ezo zengoberera",
'tog-watchdeletion'           => "Empapula zenzigyawo ziteekebwenga ku lukalala lw'ezo zengoberera",
'tog-minordefault'            => "Bulijjo, enkyukakyuka z'okola zirambibwe nti ntono",
'tog-previewontop'            => "Okulagako kubeerenga waggulu w'ekifo w'owandikira",
'tog-previewonfirst'          => 'Buli lwensooka okukyusa olupapula, ndagangako byenkoze',
'tog-nocache'                 => "Ekyandaaza kiremenga kutereka koppi z'empapula z'okebera",
'tog-enotifwatchlistpages'    => "Nsindikiranga 'E-mail' empapula zengoberera buli lwe zikolebwako enkyukakyuka",
'tog-enotifusertalkpages'     => "Nsindikiranga 'E-mail' olupapula lwange olwa 'Yogera nange' buli lwe lukyusibwamu",
'tog-enotifminoredits'        => "Nsindikiranga 'E-mail' enkyukakyuka ne bwe ziba ntono",
'tog-enotifrevealaddr'        => "Mu 'E-mail' ez'amawulire, endagiriro eyange eya 'E-mail' erabikenga",
'tog-shownumberswatching'     => "Ndaganga obungi bw'abagoberera olupapula",
'tog-oldsig'                  => 'Omukono gwo kakano:',
'tog-fancysig'                => 'Omukono gubemu obubonero bwa ki-wiki (naye nga tegufuuka nyunzi)',
'tog-externaleditor'          => 'Wandikisanga puloguramu eri ku kompyuta yo (kyetaagisa bumanyirivu bungi, kubanga wetaaga okutegeka kompyuta yo mu ngeri ezitali za bulijjo. [http://www.mediawiki.org/wiki/Manual:External_editors Okutangaaza okusingawo.])',
'tog-externaldiff'            => "Kozesanga puloguramu ey'oku kompyuta yo okukebera njawulo wakati w'ebiwandike (kyetaagisa bumanyirivu bungi, wetaaga ntegeka ezitali za bulijjo ku kompyuta yo. [http://www.mediawiki.org/wiki/Manual:External_editors Okutangaaza okusingawo.])",
'tog-showjumplinks'           => 'Wabeerewo enyunzi eza "Genda ku"',
'tog-uselivepreview'          => 'Enkyukakyuka ze nkoze zirabikirewo nga tekyetaagisiza kumala kunyiga ppeesa (kyetaagisa JavaScript)(Kikyagezesebwa)',
'tog-forceeditsummary'        => 'Ŋambaako bwe mba ŋenda okuleka nga sinnyonyodde bye nkyusizza',
'tog-watchlisthideown'        => "Nze bye nkyusizza bireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-watchlisthidebots'       => "Ezikyusidwa zibboti zireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-watchlisthideminor'      => "Nkyukakyuka ntono zireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-watchlisthideliu'        => "Ezikyusidwa abayingidde mu sisitemu zireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-watchlisthideanons'      => "Ezikyusidwa abat'emanyisizza zireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-watchlisthidepatrolled'  => "Ezirawunidwa zireme okulabikira mu lukalala lw'empapula ze ngoberera",
'tog-ccmeonemails'            => 'Bwe nsindika email, nange nfunengako koppi',
'tog-diffonly'                => "Bwe mba nga nkebera enjawulo wakati w'empandika z'olupapula, ebikyuse ku lupapula byokka bye biba birabika.",
'tog-showhiddencats'          => 'Amatuluba agabeera makise mu bya bulijjo galabikenga',
'tog-norollbackdiff'          => 'Okujjulula nga kuwedde, tolaga bigerageranya ebikyuse',

'underline-always'  => 'Bulijjo',
'underline-never'   => 'Nedda',
'underline-default' => "Puloguramu y'esalawo",

# Font style option in Special:Preferences
'editfont-style'     => "Enkula y'ennukuta mu katundu w'owandikira:",
'editfont-default'   => "Puloguramu y'esalawo",
'editfont-monospace' => "Ennukuta n'obubonero eby'ebyenkanankana",
'editfont-sansserif' => 'Embulaserifu',
'editfont-serif'     => 'Serifu',

# Dates
'sunday'        => 'Sande',
'monday'        => 'Bbalaza',
'tuesday'       => 'Lwakubiri',
'wednesday'     => 'Lwakusatu',
'thursday'      => 'Lwakuna',
'friday'        => 'Lwakutaano',
'saturday'      => 'Lwamukaaga',
'sun'           => 'San',
'mon'           => 'Bal',
'tue'           => 'Lw2',
'wed'           => 'Lw3',
'thu'           => 'Lw4',
'fri'           => 'Lw5',
'sat'           => 'Lw6',
'january'       => 'Gusooka',
'february'      => 'Gwakubiri',
'march'         => 'Gwakusatu',
'april'         => 'Gwakuna',
'may_long'      => 'Gwakutaano',
'june'          => 'Gwamukaaga',
'july'          => 'Gwamusanvu',
'august'        => 'Gwamunaana',
'september'     => 'Gwamwenda',
'october'       => 'Gwakkumi',
'november'      => 'Gwakkuminogumu',
'december'      => 'Gwakkuminebiri',
'january-gen'   => 'Gusooka',
'february-gen'  => 'Gwakubiri',
'march-gen'     => 'Gwakusatu',
'april-gen'     => 'Gwakuna',
'may-gen'       => 'Gwakutaano',
'june-gen'      => 'Gwamukaaga',
'july-gen'      => 'Gwamusanvu',
'august-gen'    => 'Gwamunaana',
'september-gen' => 'Gwamwenda',
'october-gen'   => 'Gwakkumi',
'november-gen'  => 'Gwakkuminogumu',
'december-gen'  => 'Gwakkuminebiri',
'jan'           => 'Gu1',
'feb'           => 'Gw2',
'mar'           => 'Gw3',
'apr'           => 'Gw4',
'may'           => 'Gw5',
'jun'           => 'Gw6',
'jul'           => 'Gw7',
'aug'           => 'Gw8',
'sep'           => 'Gw9',
'oct'           => 'Gw10',
'nov'           => 'Gw11',
'dec'           => 'Gw12',

# Categories related messages
'pagecategories'                 => '{{PLURAL:$1|Tuluba|Matuluba}}',
'category_header'                => 'Empapula eziri mu ttuluba lya "$1"',
'subcategories'                  => 'Amatabi',
'category-media-header'          => 'Mediya eziri mu ttuluba lya "$1"',
'category-empty'                 => "''Ettuluba lino temuli mpapula oba mediya.''",
'hidden-categories'              => '{{PLURAL:$1|Ettuluba erikise|Amatuluba amakise}}',
'hidden-category-category'       => 'Amatuluba agakisidwa',
'category-subcat-count'          => '{{PLURAL:$2|Ettuluba lino lirimu ettabi lino lyokka:|Ettuluba lino lirimu {{PLURAL:$1|ettabi lino:|amatabi $1 gano}}, ku $2 awamu.}}',
'category-subcat-count-limited'  => 'Ettuluba lino lirimu {{PLURAL:$1|ettabi lino|amatabi gano $1}}.',
'category-article-count'         => '{{PLURAL:$2|Olupapula olumenyedwa wano lwe lwokka oluli mu ttuluba lino.|{{PLURAL:$1|Olupapula luno lwe luli|Empapula $1 zino ze ziri}} mu ttuluba lino. Lirimu empapula $2 awamu.}}',
'category-article-count-limited' => '{{PLURAL:$1|Olupapula luno luli|Empapula zino $1 ziri}} mu ttuluba lino.',
'category-file-count'            => "{{PLURAL:$2|Fayiro emenyedwa wano ye yokka eri mu ttuluba lino.|{{PLURAL:$1|Fayiro eno y'eri|Fayiro $1 zino ze ziri}} mu ttuluba lino. Lirimu fayiro $2 awamu.}}",
'category-file-count-limited'    => '{{PLURAL:$1|Fayiro eno eri|Fayiro zino $1 ziri}} mu ttuluba lino.',
'listingcontinuesabbrev'         => 'era...',
'index-category'                 => "Empapula ezikkirizidwa okuteekebwa ku nkalala z'enfo ezinoonyesebwa",
'noindex-category'               => "Empapula ezigaanidwa okuteekebwa ku nkalala z'enfo ezinoonyesebwa",

'mainpagetext'      => 'MediaWiki kati ewangidwa ku sisitemu yo',
'mainpagedocfooter' => "Okuyiga ku nkozesa ya sofutiweya owa wiki, kebera [http://meta.wikimedia.org/wiki/Help:Contents Okulagirira Abakozesa].

== Amagezi agakuyamba okutandika ==
* [http://www.mediawiki.org/wiki/Manual:Configuration_settings Lukalala lw'eby'enteekateeka yo]
* [http://www.mediawiki.org/wiki/Manual:FAQ Ebiter'okubuuzibwa ku MediaWiki]
* [https://lists.wikimedia.org/mailman/listinfo/mediawiki-announce Wewandise ofunenga amawulire aga email ag'ebifa ku MediaWiki]",

'about'         => 'Okutangaaza',
'article'       => 'Lupapula lwa nsonga',
'newwindow'     => '(bijjira mu kadirisa kapya)',
'cancel'        => 'Biveeko',
'moredotdotdot' => 'Era...',
'mypage'        => 'Enfo yange',
'mytalk'        => 'Yogera nange',
'anontalk'      => "Yogera-nange ow'endagiriro ya IP eno",
'navigation'    => 'Endagiriro',
'and'           => '&#32;ne',

# Cologne Blue skin
'qbfind'         => 'Noonya',
'qbbrowse'       => 'Lambula',
'qbedit'         => 'Kyusa',
'qbmyoptions'    => 'Empapula zange',
'qbspecialpages' => 'Empapula enjawule',
'faq'            => 'Ebitera okubuuzibwa',
'faqpage'        => 'Project:Ebitera okubuuzibwa ku',

# Vector skin
'vector-action-addsection' => 'Tandikawo emboozi endala',
'vector-action-delete'     => 'Gyawo olupapula luno',
'vector-action-move'       => 'Simbuliza',
'vector-action-protect'    => 'Ssiba',
'vector-action-undelete'   => 'Zawo',
'vector-action-unprotect'  => 'Gyako ebikugizo',
'vector-namespace-main'    => 'Lupapula',
'vector-view-create'       => 'Lukolewo',
'vector-view-edit'         => 'Kyusa',
'vector-view-history'      => 'Ennanda ya fayiro eno',
'vector-view-view'         => 'Soma',
'vector-view-viewsource'   => "Kebera obulambike obw'ennono obw'olupapula luno",
'actions'                  => "By'oyinza okukola",
'namespaces'               => 'Makuŋaanyizo',

'errorpagetitle'    => 'Kiremya',
'returnto'          => 'Dda ku $1.',
'tagline'           => 'Bisangiddwa ku {{SITENAME}}',
'help'              => 'Nyamba',
'search'            => 'Noonya',
'searchbutton'      => 'Noonya',
'go'                => 'Nona',
'searcharticle'     => 'Nona',
'history'           => "Ennanda y'olupapula luno",
'history_short'     => 'Ennanda',
'updatedmarker'     => 'ebikyusidwa okuva lwe nasemba okukebera',
'info_short'        => 'Okumanyisa',
'printableversion'  => 'Entereeza eyanguya okukubisa',
'permalink'         => 'Kolawo enyunzi egguka ku lupapula luno nga bwe lufaanana ku ssaawa eno',
'print'             => 'Kubisa',
'edit'              => 'Kyusa',
'create'            => 'Kolawo',
'editthispage'      => 'Olupapula luno lukyusemu',
'create-this-page'  => 'Olupapula luno lukolewo',
'delete'            => 'Gyawo olupapula luno',
'deletethispage'    => 'Olupapula luno lugyewo',
'undelete_short'    => 'Julula {{PLURAL:$1|enkyukakyuka emu|enkyukakyuka $1}}',
'protect'           => 'Ssiba',
'protect_change'    => 'lusibe/lusumulule',
'protectthispage'   => 'Siba olupapula luno',
'unprotect'         => 'Gyako ebikugizo',
'unprotectthispage' => 'Sumulula olupapula luno',
'newpage'           => 'Lupapula lupya',
'talkpage'          => "W'ebirowozo ku lupapula luno",
'talkpagelinktext'  => 'Yogera nange',
'specialpage'       => 'Olupapula olwawule',
'personaltools'     => "Ebikola ku akawunti n'enfo yo",
'postcomment'       => 'Kitundu kipya',
'articlepage'       => 'Kebera olupapula',
'talk'              => 'Emboozi',
'views'             => "Kyusa endabika ya by'olaba wano",
'toolbox'           => 'Ebikozesebwa',
'userpage'          => 'Kebera enfo ya memba',
'projectpage'       => 'Kebera ekkuŋaanizo erya kawefube ono',
'imagepage'         => 'Kebera olupapula oluliko ekifaananyi',
'mediawikipage'     => "Kebera olupapula lw'obubaka",
'templatepage'      => 'Kebera olutiba',
'viewhelppage'      => 'Kebera olupapula oluliko obuyambi',
'categorypage'      => "Kebera olupapula lw'ettuluba lino",
'viewtalkpage'      => "Kebera okuwanyisagana kw'ebirowozo",
'otherlanguages'    => 'Mu nnimi ndala',
'redirectedfrom'    => '(Oleetedwa wano okuva ku $1)',
'redirectpagesub'   => 'Olupapula luno lukutwalabutwazi ku lunnaalwo',
'lastmodifiedat'    => 'Luno olupapula lwasemba okukyusibwamu ku $2, $1.',
'viewcount'         => 'Luno olupapula lwakasomebwa {{PLURAL:$1|omurundi gumu|emirundi $1}}.',
'protectedpage'     => 'Luno olupapula terukyusibwamu',
'jumpto'            => 'Genda ku:',
'jumptonavigation'  => 'Ndagiriro',
'jumptosearch'      => 'kunoonya',
'view-pool-error'   => "Tukwetondera olw'obutasabola okukuwereza olupapula lw'oyagala okulaba ku saawa eno.
Olw'obungi bw'abakebera olupapula olwo, kompyuta zaffe tezisobola kwongerako mulala.
Lindako akaseera oddemu ogezeeko okulukebera.

$1",

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'aboutsite'            => 'Okutangaaza ku {{SITENAME}}',
'aboutpage'            => 'Project:Okutangaaza ku',
'copyright'            => 'Ebiri kuno bifugibwa $1.',
'copyrightpage'        => "{{ns:project}}:Ebikugizo eby'obwa nannyini",
'currentevents'        => 'Ebibindabinda',
'currentevents-url'    => 'Project:Ebibindabinda',
'disclaimers'          => "Okutangaaza ku kkomo ery'obuvunaaniro bwaffe obw'omu mateeka",
'disclaimerpage'       => "Project:Okutangaaza ku kkomo ery'obuvunaaniro bwaffe obw'omu mateeka",
'edithelp'             => 'Nyamba',
'edithelppage'         => "Help:Obuyambi ku by'okukyusakyusa",
'helppage'             => 'Help:Endagiriro',
'mainpage'             => 'Olupapula Olusooka',
'mainpage-description' => 'Olupapula Olusooka',
'policy-url'           => "Project:Amateeka n'enkola",
'portal'               => 'Embuga',
'portal-url'           => 'Project:Embuga',
'privacy'              => 'Enkola yaffe ku kukuuma ebikufako',
'privacypage'          => 'Project:Enkola yaffe ku kukuuma ebikufako',

'badaccess'        => 'Endukusa zo tezikukkiriza kukola ku bino',
'badaccess-group0' => 'Ekikolwa ekyo tolina buyinza okukituukiriza.',
'badaccess-groups' => 'Ekikolwa ekyo kikkirizibwa abo bokka abali mu {{PLURAL:$2|kiti kya|kimu ku biti bino}}: $1.',

'versionrequired'     => "Kyetaagisa MediaWiki ey'oluwandika $1",
'versionrequiredtext' => "Olupapula luno lwetaagisa MediaWiki ey'oluwandika $1.<br />
Kebera ku [[Special:Version|lukalala lw'empandika za MediaWiki]].",

'ok'                      => 'Kale',
'retrievedfrom'           => 'Bino bigyidwa ku "$1"',
'youhavenewmessages'      => 'Ofunye $1 ($2).',
'newmessageslink'         => 'obubaka',
'newmessagesdifflink'     => "obusing'obupya",
'youhavenewmessagesmulti' => 'Ku $1 bakuweerezza obubaka',
'editsection'             => 'kyusa',
'editold'                 => 'kyusa',
'viewsourceold'           => "kebera obulambike obw'ennono obw'olupapula luno",
'editlink'                => 'lukyusemu',
'viewsourcelink'          => "kebera obulambike obw'ennono obw'olupapula luno",
'editsectionhint'         => 'Nyiga wano okukyusaamu ekitundu: $1',
'toc'                     => 'Ebirimu',
'showtoc'                 => 'ndaga endagiriro',
'hidetoc'                 => 'kisa endagiriro',
'thisisdeleted'           => 'Oyagala okulaba oba okuzzawo $1?',
'viewdeleted'             => 'Oyagala okulaba $1?',
'restorelink'             => '{{PLURAL:$1|oluwandika olwagyibwawo olumu|empandika ezagyibwawo $1}}',
'feedlinks'               => 'Mukutu gwa mawulire:',
'feed-invalid'            => "Ekika ky'omukutu gw'amawulire tekimanyidwa.",
'feed-unavailable'        => 'Tekisobose okufunayo mikutu gya mawulire',
'site-rss-feed'           => "Mukutu ogw'amawulire ogw'ekika kya RSS ogw'oku $1",
'site-atom-feed'          => "Mukutu ogw'amawulire ogw'ekika kya Atom ogw'oku $1",
'page-rss-feed'           => 'Mukutu gw\'amawulire ogw\'ekika kya RSS ogw\'oku "$1"',
'page-atom-feed'          => 'Mukutu ogw\'amawulire ogw\'ekika kya Atom "$1"',
'red-link-title'          => '$1 (olupapula olwogera ku kino terunakolebwawo)',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'Lupapula',
'nstab-user'      => 'Enfo ya memba',
'nstab-media'     => 'Lupapula lwa mediya',
'nstab-special'   => 'Olupapula olwawule',
'nstab-project'   => 'Ekkuŋaanizo erya kawefube',
'nstab-image'     => 'Fayiro',
'nstab-mediawiki' => 'Obubaka',
'nstab-template'  => 'Lutiba',
'nstab-help'      => 'Buyambi',
'nstab-category'  => 'Ttuluba lya',

# Main script and global functions
'nosuchaction'      => 'Ekikolwa ekyo tekisoboka',
'nosuchactiontext'  => "Ekikolwa ekikongojedwa mu URL tekisoboka.<br />
Oyinza okuba nga URL wagiwandise bubi, oba yo URL y'eyinza okuba nga ya nsobi.<br />
Kiyinza ate okuba nti sofutiweya {{SITENAME}} gy'ekozesa erimu ebitali bituufu.",
'nosuchspecialpage' => 'Olwo olupapula olwawule teruliwo',
'nospecialpagetext' => '<strong>Onoonyezza olupapula olwawule olutaliwo.</strong>

Ku lupapula "[[Special:SpecialPages|{{int:specialpages}}]]" kuliko olukalala lw\'empapula enjawule.',

# General errors
'error'                => 'Kiremya',
'databaseerror'        => 'Waliwo kiremya ku ggwanika lya data',
'dberrortext'          => 'Waliwo kiremya avudde ku mpandika y\'ekiragiro ekinoonyeza mu ggwanika lya data.<br />
Ayinza okuba nga azze lwa nsobi mu sofutiweya wa lyo.<br />
Ekiragiro ekinoonyeza mu ggwanika lya data ekisembye okuyisibwa kiri:<br />
<blockquote><tt>$1</tt></blockquote>
ekisangibwa mu mukolo gwa puloguramu "<tt>$2</tt>".<br />
Obubaka obuvudde mu ggwanika lya data obufa ku kiremya buli "<tt>$3: $4</tt>".',
'dberrortextcl'        => 'Waliwo kiremya avudde ku mpandika y\'ekiragiro ekinoonyeza mu ggwanika lya data.<br />
Ekiragiro ekinoonyeza mu ggwanika lya data ekisembye okuyisibwa kiri:<br />
"$1" <br />
ekisangibwa mu mukolo gwa mu puloguramu "$2".<br />
Obubaka obuvudde mu ggwanika lya data obufa ku kiremya buli "$3: $4"',
'laggedslavemode'      => "'''Kulabula:''' Olupapula luyinza obutabaamu ebyakalukyusibwamu.",
'readonly'             => 'Eggwanika lya data terikkiriza kulikyusamu',
'enterlockreason'      => "Wandikawo ensonga esibizza eggwanika lya data, nga olaga ddi lw'olisuubira okusumululwa",
'readonlytext'         => "Eggwanika lya data lino ku ssaawa eno terikkiriza okulikyusamu. Kino kitera okubawo nga balikolako, balyoke balisumulule.<br />
<br />
Kuno kwe kunnyonyola kw'omuteesiteesi eyalisibye: $1",
'missing-article'      => "Mu ggwanika ya data mubadde musuubidwamu bigambo ebikola olupapula \"\$1\" \$2, tebisangidwamu.

Kino kitera okubawo singa likoda y'enjawulo mu mpandika z'olupapula eba nsobu oba singa enyunzi egguka
ku nnanda yalwo eba nga egyidwawo.

Ebyo bwe biba nga ssi bye bikireesewo, oyinz'okuba nga ozudde nsobi mu sofutiweya ono.
Ensobi eno gimanyise [[Special:ListUsers/sysop|omuteesiteesi]], nga omulaga n'endagiriro (URL) kw'ogisanze.",
'missingarticle-rev'   => '(olukyusa#: $1)',
'missingarticle-diff'  => '(Enjawulo wakati wa: $1, $2)',
'readonly_lag'         => "Okukukkiriza enkyukakyuka mu ggwanika lya data lino kuyimirizidwamu, kompyuta eziriko amawanika ga data amazibizi zisobole okugakwataganya n'eggwanika lya data ery'ennono",
'internalerror'        => "Puloguramu ey'oku wiki efunye kirimya munda mwayo",
'internalerror_info'   => "Puloguramu ey'oku wiki efunye kirimya munda mwayo: $1",
'fileappenderrorread'  => '"$1" nnemedwa okugisoma ndyoke ngiwayireko ebipya.',
'fileappenderror'      => '"$2" nnemedwa okugiwayirako "$1".',
'filecopyerror'        => 'Nnemedwa okuteeka kkopi ya fayiro "$1" mu "$2".',
'filerenameerror'      => 'Fayiro "$1" nnemedwa okugikyusa erinnya lifuuke "$2".',
'filedeleteerror'      => 'Nnemedwa okugyawo fayiro "$1".',
'directorycreateerror' => 'Nnemedwa okukolawo etterekero "$1".',
'filenotfound'         => 'Fayiro "$1" embuze.',
'fileexistserror'      => 'Nnemedwa okuwandika fayiro "$1": Yakolebwawo dda',
'unexpected'           => 'Waliwo ekivaamu ekitasuubirwa: "$1"="$2".',
'formerror'            => 'Kiremya: nnemedwa okusindika foomu',
'badarticleerror'      => 'Ku lupapula luno ekikolwa ekyo tekisoboka.',
'cannotdelete'         => 'Tekisobose okugyawo olupapula oba fayiro "$1".<br />
Kisoboka nti waliwo eyakwesoose.',
'badtitle'             => 'Buzibu ku linnya lya lupapula',
'badtitletext'         => "Onoonyezza erinnya ly'olupapula eritakkirizibwa, oba ery'olupapula olwereere, oba ery'oluli ku wiki endala nga teruyungidwa ku eno obulungi.<br />
Erinnya eryo liyinza ate okubaamu ennukuta oba obubonero ebitakkirizibwa mu mannya ga mpapula.",
'perfcached'           => "Data eddako wano eva mu ggwanika zzibizi era eyinz'obutatuukana n'eyennono.",
'perfcachedts'         => "Data eddako wano eva mu ggwanika zzibizi, yasemba okutuukanizibwa n'ey'ennono ku saawa $3, nga $2.",
'querypage-no-updates' => 'Ku ssaawa eno olupapula luno terukkiriza kukyusibwamu.<br />
Data eruliko ejjakugira nga tekyuka.',
'wrong_wfQuery_params' => 'wfQuery() kirimu paramita ensobu zino<br />
Mukolo: $1<br />
Ekiragiro ekinoonyeza mu ggwanika lya data: $2',
'viewsource'           => "Kebera obulambike obw'ennono obw'olupapula luno",
'viewsourcefor'        => 'obwa $1',
'actionthrottled'      => 'Ekikolwa kigaanidwa',
'actionthrottledtext'  => "Okulwanyisa abasindika obubaka kiyaaye, twateekawo ekkomo ery'emirundi omuntu gy'ayinza okukola ekikolwa ekyo.<br />
Gwe olituuseeko.<br />
Lindako eddakiika entonotono oly'oke oddemu okugezako ekikolwa.",
'protectedpagetext'    => 'Olupapula luno luliko ekikugizo ekirugaana okukyusibwako.',
'viewsourcetext'       => "Obulambe obw'ekiwandike eky'ennono eky'olupapula luno osobola okubukebera n'okubugyamu koppi:",
'protectedinterface'   => "Olupapula luno nnono y'ebigambo eby'oku bitundu bya sofutiweya abagikozesa bye balaba.<br />
Luliko ebikugizo ebirugaana okwonooebwa.",
'editinginterface'     => "'''Kulabula:''' Okyusa olupapula sofutiweya kw'egya ebigambo byayo.
Enkyukakyuka z'okola wano zigyakubaako kye zikola ku ngeri abantu gye bakozesaamu enfo eno.",
'sqlhidden'            => '(Waliwo wo ebya SQL ebibikkidwa)',
'cascadeprotected'     => 'Olupapula luno lulandideko ekikugizo ekirugaana okukyusibwako ekisibuka ku {{PLURAL:$1|lunnaalwo luno olulukozesa|zinnalwo zino ezirukozesa}}:<br />
$2',
'namespaceprotected'   => "Tolina buyinza bwa kukyusa ku mpapula ez'omu kkuŋaanizo erya '''$1'''.",
'customcssjsprotected' => 'Tolina buyinza bwa kukyusa ku lupapula luno, kubanga lufuga enteekateeka eza memba omulala.',
'ns-specialprotected'  => 'Empapula enjawule tezikukkiriza kuzikyusaako.',
'titleprotected'       => '[[User:$1|$1]] ataddewo ekikugizo ekigaana okukozesa omutwe guno.<br />
Ensonga gy\'awadde eri nti "\'\'$2\'\'".',

# Virus scanner
'virus-badscanner'     => "Kiremya mu nteekateeka: ekinoonya vayirasi kino tekimanyidwa: ''$1''",
'virus-scanfailed'     => 'okunoonya vayirasi kulemye (obubaka buli $1)',
'virus-unknownscanner' => 'ekinoonya vayirasi ekitamanyidwa:',

# Login and logout pages
'logouttext'                 => "'''Kati ovuddemu.'''

Osobola okusigala nga okozesa {{SITENAME}} nga at'eyanjudde, ate osobola [[Special:UserLogin|n'okuddamu okuyingira]] nga bw'obadde oba nga okozesezza ery'obwa memba eddala.
Wekkaanye, empapula ezimu ziyinza okukweyolekera nga bwe zibadde nga oyingidde - okutuusa lw'okunkumula eggwanika ezzibizi erya kalambula-neti yo.",
'welcomecreation'            => "== $1 tukwanirizza! == <br />
Akawunti yo ekoledwa.<br />
Tewerabira kwetereereza [[Special:Preferences|enteekateeka yo ey'oku {{SITENAME}}]].",
'yourname'                   => "Ery'obwa memba",
'yourpassword'               => 'Ekigambo ekikuumi',
'yourpasswordagain'          => 'Ddamu ekigambo ekikuumi',
'remembermypassword'         => 'Tereka ekigambo kyange ekikuumi ku kompyuta eno',
'yourdomainname'             => 'Linnya lya twale lya kayungirizi lyo:',
'externaldberror'            => "Waliwo kiremya mu ggwanika lya data ekozesebwa okukakasa bamemba oba tokkirizibwa okukyusa ku akawunti yo ey'awalala.",
'login'                      => 'Yingira',
'nav-login-createaccount'    => 'Yingira / kolawo akawunti',
'loginprompt'                => 'Okuyingira {{SITENAME}}, kalambula-neti yo erina okukkirizako kuki.',
'userlogin'                  => 'Yingira / kolawo akawunti',
'userloginnocreate'          => 'Yingira',
'logout'                     => 'Vaamu',
'userlogout'                 => 'Vaamu',
'notloggedin'                => 'Tonnayingira',
'nologin'                    => "Akawunti wafuna? '''$1'''.",
'nologinlink'                => 'Funa akawunti',
'createaccount'              => 'Kolawo akawunti',
'gotaccount'                 => "Akawunti wafuna? '''$1'''.",
'gotaccountlink'             => 'Yingira',
'createaccountmail'          => 'Akawunti gikole ne E-mail',
'badretype'                  => "Ebigambo ebikuumi by'owandise tebifaanagana.",
'userexists'                 => "Ery'obwa memba ly'owandise wali omulala alirina.<br />
Londa eddala.",
'loginerror'                 => 'Okuyingira kuzzeko kiremya:',
'createaccounterror'         => 'Nemedwa okukolawo akawunti: $1',
'nocookiesnew'               => "Akawunti w'eri, naye sisitemu tekuyingizza.<br />
Okuyingira {{SITENAME}} nga memba kyesigamizidwa ku bujjukiza.<br />
Kalambulanetti yo kakano etegekedwa butakkiriza obujjukiza obwo.<br />
Okusobola okuyingira, kyusa entegeka ya yo ebukkirize eryoke okozese ery'obwa memba n'ekigambo ekikuumi byo.",
'nocookieslogin'             => 'Okuyingira {{SITENAME}} nga memba kyesigamizidwa ku bujjukiza.<br />
Kalambulanetti yo kakano etegekedwa butakkiriza obujjukiza obwo.<br />
Okusobola okuyingira, kyusa entegeka ya yo ebukkirize eryoke oddemu okugeza okuyingira.',
'noname'                     => "Towandise linnya ly'obwa memba eriyinz'okukkirizibwa.",
'loginsuccesstitle'          => 'Oyingidde',
'loginsuccess'               => "'''Kati oyingidde mu {{SITENAME}} nga okozesa erinnya \"\$1\".'''",
'nosuchuser'                 => "Tewali memba akozesa lya \"\$1\".<br />
Ery'obwa memba bw'okyusa obunene bw'ennukuta z'oliwandisa obeera owandise eddala.<br />
Kebera bw'oliwandise, oba [[Special:UserLogin/signup|kolawo akawunti empya]].",
'nosuchusershort'            => 'Tewali memba akozesa lya "<nowiki>$1</nowiki>".<br />
Kebera bw\'oliwandise.',
'nouserspecified'            => "Kyetaagisa owandikewo erinnya ly'obwa memba.",
'login-userblocked'          => 'Memba ono agaanidwa. Takkirizibwa kuyingira.',
'wrongpassword'              => "Ekigambo ekikuumi ky'oyingizza ssi kituufu.<br />
Ddamu ogezeeko.",
'wrongpasswordempty'         => 'Tewawandise kigambo kikuumi.<br />
Ddamu ogezeeko.',
'passwordtooshort'           => 'Ekigambo ekikuumi kiteekwa okubaamu {{PLURAL:$1|akabonero wakiri kamu|obubonero obutakka wansi wa $1}}.',
'password-name-match'        => "Tokkirizibwa kukozesa linnya lyo ery'obwa memba ng'ekigambo ekikuumi.",
'mailmypassword'             => 'Nsindikira ekigambo ekikuumi ekipya',
'passwordremindertitle'      => "Ekigambo ekikuumi eky'oku {{SITENAME}} ekipya. Kya kiseerabuseera.",
'passwordremindertext'       => 'Waliwo eyayimidde ku ndagiriro eya IP $1 (tusuubiri nti ye ggwe) n\'asaba ekigambo ekikuumi eky\'oku {{SITENAME}} ($4) ekipya.<br />
Memba "$2" tumukoleddewo ekigambo ekikuumi eky\'ekiseerabuseera, "$3". Kino bwe kiba nga kye kyewagenderedde,<br />
wetaaga kugenda kati oyingire akawunti yo okyuse ekigambo ekikuumi okolewo ekya ddala.<br />
Ekigambo eky\'ekiseerabuseera kijjakuleker\'awo okukola mu {{PLURAL:$5|lunaku lumu|nnaku $5}}.',
'noemail'                    => 'Tetulina ndagiriro eya E-mail eya memba "$1".',
'noemailcreate'              => 'Wetaaga kuwayo ndagiriro eya E-mail ekola',
'passwordsent'               => 'Ekigambo ekikuumi ekipya tukisindise ku E-mail eyatuwebwa nga eya "$1".<br />
Bw\'omala okukifuna nga oryoka oddamu okuyingira.',
'blocked-mailpassword'       => "Okulwanyisa nkozesa mbi, tetukkiriza okukyusa eby'oku {{SITENAME}} okuva ku ndagiriro eya IP kw'oyimye.<br />
Kino kitwaliramu n'obutakkiriza okufuna ebigambo bikuumi ebipya.",
'eauthentsent'               => "Tukusindikidde E-mail ku ndagiriro gy'ova kutuwa, osobole okugitukakasiza.<br />
Soma E-mail eyo ogoberore ebiragiro ebigirimu otukakasize nti endagiriro empya ddala yiyo,<br />
tulyoke tusobole okwongera okugikuwererezangako obubaka.",
'throttled-mailpassword'     => "Nyini akawunti eno twakamusindikira okujjukiza ekyama kye {{PLURAL:$1|, n'essaawa tennayita|mu ssaawa $1 ezaakayita}}.<br />
Olw'okulwanyisa enkozesa mbi, essaawa {{PLURAL:$1|emu e|$1 zi}}mala okuyitawo tulyoke tukkirize okukiddamu n'ate.",
'mailerror'                  => 'Okusindika E-mail kuzzemu kiremya: $1',
'acct_creation_throttle_hit' => "Ku lunaku olumu luno, abajja ku wiki eno nga basinzidde ku ndagiriro eya IP gy'oliko baakakolawo {{PLURAL:$1|akawunti 1|akawunti $1}}. Tekikkirizibwa kukolawo zisingawo obungi mu budde obwo.<br />
Olw'ensonga eno, ku ssaawa eno, abasinzira ku ndagiriro gy'oliko tebasobola kukolawo akawunti.",
'emailauthenticated'         => 'Endagiriro yo eya E-mail twagikakasa ku ssaawa $3, nga $2.',
'emailnotauthenticated'      => "Endagiriro yo eya E-mail tennakakasibwa.<br />
Bw'en'emala okukakasibwa nga by'olonze ku bya E-mail wano bitandika okukola.",
'noemailprefs'               => "By'olondako wano byetaaga owandikewo endagiriro yo eya E-mail biryoke bikole.",
'emailconfirmlink'           => 'Tukakasize endagiriro yo eya E-mail',
'invalidemailaddress'        => "Empandika ey'endagiriro eya E-mail gy'otaddewo yandibaamu ensobi.<br />
Gigolole oba lekawo nga w'ereere.",
'accountcreated'             => 'Akawunti ekoleddwa',
'accountcreatedtext'         => "Akawunti ey'obwa memba eya $1 ekoleddwa.",
'createaccount-title'        => "Okukolawo akawunti ey'oku {{SITENAME}}",
'createaccount-text'         => 'Waliwo eyakozewo akawunti ey\'oku {{SITENAME}} ($4) nga akozesa endagiriro eyiyo eya E-mail.<br />
Erina erinnya ly\'obwa memba "$2", ate ekyama kiri "$3".<br />
Wandigenze kakati n\'oyingira akawunti eyo okyuse ekyama.<br />
<br />
Akawunti eno bw\'obanga togyetaaga, gireke tunaagigyawo.',
'usernamehasherror'          => "Ery'obwa memba terikkirizibwa kubaamu akabonero ak'obusazesaze (#)",
'login-throttled'            => "Ogezeza okuyingira mu sisitemu emilundi egiyitiridde obungi kaseera kano.<br />
Sooka olindeko akaseera okuddamu n'ate.",
'loginlanguagelabel'         => 'Lulimi: $1',
'suspicious-userlogout'      => "Sisitemu ezize ekiragiro kyo eky'okugivaamu kubanga kirabise nga ekivudde mu kalambulanetti enfu<br />
oba mu puloguramu etereka n'eddamu okuyisa ebiragiro ebivudde awalala.",

# Password reset dialog
'resetpass'                 => 'Kyusa ekigambo ekikuumi',
'resetpass_announce'        => "Weyambisa ekyama eky'ekiseerabuseera okuyingira.<br />
Okuyingirira ddala, wetaaga okuwandika wano ekinaaba ekyama kyo ekya ddala:",
'resetpass_header'          => "Kyusa ekigambo ekikuumi eky'oku akawunti eno",
'oldpassword'               => 'Ekigambo ekikuumi ekikadde:',
'newpassword'               => 'Ekigambo ekikuumi ekipya:',
'retypenew'                 => 'Ddamu ekikagambo ekikuumi ekipya ekyo:',
'resetpass_submit'          => 'Kaza ekyama oyingire',
'resetpass_success'         => 'Ekigambo kyo ekikuumi kikyusidwa!<br />
Kati oyingira...',
'resetpass_forbidden'       => 'Tekikkirizibwa okukyusa ebigambo ebikuumi',
'resetpass-no-info'         => 'Okukola ku lupapula luno obutereevu, wetaaga okuba nga oyingidde sisitemu.',
'resetpass-submit-loggedin' => 'Kyusa ekigambo ekikuumi',
'resetpass-submit-cancel'   => 'Bisazemu',
'resetpass-wrong-oldpass'   => "Okozesezza ekyama eky'ekiseerabuseera oba ekyaddala ekitakola.<br />
Oyinz'okuba nga wamaze okutegeka ekya ddala ekipya oba nga wakasabayo eky'ekiseerabuseera.",
'resetpass-temp-password'   => "Ekyama kyo eky'ekiseerabuseera:",

# Edit page toolbar
'bold_sample'     => "Ennukuta z'owandika wano zonna ziba nziggumivu",
'bold_tip'        => "Bw'onyiga kano, ofuna w'oyinza okuwandikira ennukuta ezo ne zivaamu nga nziggumivu",
'italic_sample'   => "Ennukuta z'owandika wano zonna ziba za italiki",
'italic_tip'      => "Bw'onyiga ku kano, ennukuta z'oddako okuwandika ziba za italiki (ez'esurise). Okuddamu okufuna ennukuta eza bulijjo, ddamu okukanyiga ko.",
'link_sample'     => 'Enyunzi yo eno egguke wa?',
'link_tip'        => "Nyiga wano ob'oyagala okukolawo enyunzi egguka ku kifo ekiri ku wiki eno",
'extlink_sample'  => 'http://www.example.com linnya lya nyunzi',
'extlink_tip'     => "Nyiga ku kano ob'oyagala okuteekawo enyunzi egguka ku kifo ekitali ku wiki eno. (genderera ne kutabulako ennukuta ezikulembedde, http:// )",
'headline_sample' => 'Mutwe omukulu',
'headline_tip'    => "Nyiga ku kano okuwandika omutwe ogw'eddaala ery'okubiri",
'math_sample'     => 'Wandika wano fomula yo',
'math_tip'        => "Bw'onyiga wano, ofuna w'osobolera okuwandika fomula ey'okubala. Okugiwandika, olina okukozesa empandika ey'enkola ya LaTeX.",
'nowiki_sample'   => 'Byowandika wano tebijjakufuulafuulibwa enkola ya wiki',
'nowiki_tip'      => "Nyiga ku kano ob'oyagala okufuna w'owandikira ebintu ebitafuulibwafuulibwa enkola ya wiki",
'image_tip'       => "Bw'onyiga ku kano, we wakomye okuwandika wajjawo enyunzi eteekawo ekifaananyi",
'media_tip'       => "Bw'onyiga ku kano, w'okomye okuwandika wajjawo enyunzi gy'okozesa okugguka ku fayiro eya mediya (eya vidiyo oba maloboozi)",
'sig_tip'         => "Nyiga ku kano ob'oyagala okuteekawo n'erinnya lyo ko n'obudde kw'omalidde bino by'okoze.",
'hr_tip'          => "Bw'onyiga ku kano ofuna olusaze olwawula mu by'owandika. (Gezaako butakozesa nyingi)",

# Edit pages
'summary'                          => "Wandika wano ebinyonyola enkyukakyuka z'okoze:",
'subject'                          => 'Ekyogerwako/Mutwe:',
'minoredit'                        => 'Eno nkyukakyuka ntono',
'watchthis'                        => 'Goberera olupapula luno',
'savearticle'                      => 'Kaza olupapula',
'preview'                          => 'Kulagako',
'showpreview'                      => 'Sooka ondageko',
'showlivepreview'                  => "Labirawo enfaanana ya by'okusiza",
'showdiff'                         => 'Ndaga bwe bikyuse',
'anoneditwarning'                  => "'''Kulabula:''' Owandika toyingidde mu sisitemu. Tujjakuwandika endagiriro eya kompyuta kwosinzidde
mu lukalala lw'enkuykakyuka ez'omu lupapula luno.",
'missingsummary'                   => "'''Okujjukiza:''' Towandise ebinnyonyola enkyukakyuka z'okoze.<br />
Bw'oddamu okunyiga \"{{int:savearticle}}\", by'okoze tebijjakubaako okunnyonyola.",
'missingcommenttext'               => 'Wandika ebigambo byo wano awaddako.',
'summary-preview'                  => 'Kuno kwe kunnyonyola kwo:',
'subject-preview'                  => 'Omutwe bwe gunaafaanana:',
'blockedtitle'                     => 'Ono agaanidwa',
'blockedtext'                      => "'''Ebikolebwa mu linnya lyo ery'obwa memba, oba okuva ku ndagiriro yo eya 'IP', bisibidwa.'''

$1 y'ataddewo natti eyo.<br />
Ensonga gy'awadde eri nti ''$2''.

* Natti eyo yateeredwako ku: $8 <br />
* Ekoma ku: $6 <br />
* Natti eteredwawo ekole ku: $7

Osobola okubyogerako ne $1 oba [[{{MediaWiki:Grouppage-sysop}}|omutesitesi]] omulala.<br />
Ekya 'Memba ono musindikire e-mail' toosobole okukikozesa okugyako nga mu [[Special:Preferences|nteekateeka]] ey'akawunti yo mulimu e-mail ennamu era nga yo teriko natti.<br />
Kakano endagiriro eya 'IP' gy'oliko eri $3, yo ennamba eya natti gyebakusibye eri #$5.<br />
Gw'ogenda okwogera naye ku natti mutegeeze ennamba oba endagiriro eyo, oba byombi.",
'autoblockedtext'                  => "'''Ebikolebwa okuva ku ndagiriro yo eya 'IP' sisitemu ebisibye kubanga yakozesebwako omuntu eyagaanibwa $1 okukola ku wiki eno.'''

Ensonga eyawebwa y'eno:<br />
:''$2''
* Natti eyo yateeredwako ku: $8 <br />
* Ekoma ku: $6 <br />
* Natti eteredwawo ekole ku: $7
<br />
Osobola okubyogerako ne $1 oba [[{{MediaWiki:Grouppage-sysop}}|omutesitesi]] omulala.<br />
Ekya 'Memba ono musindikire e-mail' toosobole okukikozesa okugyako nga mu [[Special:Preferences|nteekateeka]] ey'akawunti yo mulimu e-mail ennamu era nga yo teriko natti.<br />
<br />
Kakano endagiriro eya 'IP' gy'oliko eri $3, yo ennamba eya natti gyebakusibye eri #$5.<br />
Gw'ogenda okwogera naye ku natti mutegeeze ensonga zonna ezinnyonyodwa wano.",
'blockednoreason'                  => 'tebawadde ensonga',
'blockedoriginalsource'            => "Ensibuko ya '''$1''' eragidwa wano awaddako:",
'blockededitsource'                => "Ebigambo ebya '''by'okyusizza''' ku '''$1''' biragidwa wano awaddako:",
'whitelistedittitle'               => 'Okukyusa ku bino, wetaaga okuba nga oyingidde',
'whitelistedittext'                => '$1 olyoke osobole okukyusa ku mpapula.',
'confirmedittext'                  => "Kyetaagisa osooke okutukakasiza E-mail yo olyoke okkirizibwe okukyusa mu mpapula.<br />
Endagiriro yo eya E-mail osobola okugitutegeeza n'okugitukakasiza ku lupapula lwo olwa '[[Special:Preferences|Enteekateeka yange]]'.",
'nosuchsectiontitle'               => 'Omuko gumbuze',
'nosuchsectiontext'                => "Ogezeza okukyusa omuko ogutaliwo.<br />
Guyinz'okuba nga guggidwawo oba gujjuludwa ng'okyagukolako.",
'loginreqtitle'                    => 'Sooka oyingire',
'loginreqlink'                     => 'Yingira',
'loginreqpagetext'                 => '$1 olyoke osobole okulaba empapula ndala.',
'accmailtitle'                     => 'Ekigambo ekikuumi kisindikiddwa',
'accmailtext'                      => "Ekigambo ekikuumi ekya akawunti empya [[User talk:$1|$1]] kisindikiddwa ku $2.

Okukyusa ekigambo kino memba, ng'ayingidde mu wiki, alage ku lupapula ''[[Special:ChangePassword|change password]]''.",
'newarticle'                       => '(Lupapula lupya)',
'newarticletext'                   => "Enyunzi gy'ogenzeko egguka ku lupapula olutannakolebwawo.<br />
Oba gwe oyagala okulukolawo, wandika mu kabokisi akaddako wano.
(okuyiga ebisingawo, genda ku [[{{MediaWiki:Helppage}}|lupapula olw'obuyambi]]).<br />
Bw'obanga tewagenderedde kutuuka wano, nyigabunyizi eppeesa ery'omu kalambula-neti yo
erya '''ddayo'''.",
'anontalkpagetext'                 => "----''Olupapula olw'emboozi luno lukoledwawo at'eyanjula atakolera mu akawunti ya ku wiki eno.<br />
Kino kitwetaagisizza okumwawulira ku ndagiriro ya IP kwe yayimidde.<br />
Abantu bangi basobola okukozesa endagiriro eya IP y'emu.<br />
Bw'obanga naawe okola ng'at'eyanjudde nga owulira nti ebimu ku birowozo ebikwolekezedwa wano<br />
tebiggirawo oba tebikwatagana naawe, [[Special:UserLogin/signup|funa akawunti]] oba [[Special:UserLogin|yingira]] baleme okukutabula n'abalala abakola ng'abat'eyanjudde.",
'noarticletext'                    => "Wano tewali kyawandikidwawo.<br />
Ky'obadde onoonya osobola [[Special:Search/{{PAGENAME}}| okukinoonyeza]] ku mpapula ndala oba oyinza [{{fullurl:{{FULLPAGENAME}}|action=edit}} gwe okukiwandikako] wano.",
'noarticletext-nopermission'       => 'Wano tewali kyawandikidwawo.<br />
Ky\'obadde onoonya osobola [[Special:Search/{{PAGENAME}}| okukinoonyeza]] ku mpapula ndala oba
oyinza <span class="plainlinks">[{{fullurl:{{#Special:Log}}|page={{FULLPAGENAMEE}}}} okukinoonyeza mu nkalala z\'ebifuddeyo ebyekuusana nakyo]</span>.',
'userpage-userdoesnotexist'        => 'Akawunti y\'obwamemba "$1" teri mu nkalala za wiki eno.<br />
Sooka okakase oba ddala oyagala okukolawo olupapula olupya luno.',
'userpage-userdoesnotexist-view'   => 'Tewali akawunti ey\'obwamemba "$1".',
'blocked-notice-logextract'        => "Memba ono mu kaakano agaanidwa.<br />
Bino ebiddako bye ebikwata ku nsonga eyo mu lukalala lw'ebifuddeyo mu by'okugaana:",
'clearyourcache'                   => "'''Genderera:''' Bw'omala okubaako by'okaza, kiyinza okukwetaagisa okumala<br />
okukunkumula eggwanika ezzibizi erya kalambulanetti yo olyoke osobole okulaba enkyukakyuka z'okoze.<br />
<br />
'''Okukola kino mu ez'ekika kya Mozilla, Firefox ne Safari:''' Nyweza eppeesa erya ''Shift'' onyige ne ku kabonero<br />
aka ''Reload'', oba nyigira okumu amapeesa aga ''Ctrl'' ne ''F5'' oba aga ''Ctrl'' ne ''R'' (''Command'' ne ''R'' ku kompyuta eya Macintosh/Apple);<br />
<br />
'''Okukikolera mu ey'ekika kya Konqueror:''' Nyiga ku kabonero aka ''Reload'' oba nyiga eppeesa erya ''F5'';<br />
<br />
'''Mu ey'ekika kya Opera:''' Genda mu ''Tools → Preferences'' gy'onosangira ebikola omulimu ogwo;<br />
<br />
'''Ate mu Internet Explorer:''' Nyewza erya ''Ctrl'' nga bw'onyiga akabonero aka ''Refresh'', oba nyigira okumu aga ''Ctrl'' ne ''F5''.",
'usercssyoucanpreview'             => "'''Amagezi:''' Bw'onyiga akabonero aka \"{{int:showpreview}}\" osobola okulozako enfaanana ya CSS gw'otegese nga tosoose okugikaza.",
'userjsyoucanpreview'              => "'''Amagezi:''' Nyiga ku kabonero aka \"{{int:showpreview}}\" osobole okulozako enkola ya JavaScript gw'otegese nga tosoose okumukaza.",
'usercsspreview'                   => "'''Jukira nti CSS gw'otegese omulozakobulozi.'''<br />
'''Tannakazibwa.'''",
'userjspreview'                    => "'''Jukira nti JavaScript gw'otegese omugezesamubugezesa oba omulozakobulozi.'''<br />
'''Tannakazibwa.'''",
'updated'                          => '(Ebituukanisidwa)',
'note'                             => "'''Okunnyonyola:'''",
'previewnote'                      => "'''Kuno kugezaamubugeza; by'okoze tebinnakazibwa!'''",
'previewconflict'                  => "Okulagako kuno y'engeri ebiri w'owandikira gye binaafaananamu singa oba obikazizza.",
'session_fail_preview'             => "'''Tetusobodde okukola ku by'okyusizza olw'okubanga olutuula'''<br />
'''lwa wiki luno luzzemu okugootaana olwa data okubula.'''<br /> 
Kikwetaagisa okuddamu by'okoze. <br />
Ekyo bwe kitagonjoola ebizibu sooka [[Special:UserLogout|oveemu]] mu wiki oddemu ate okugiyingira.",
'session_fail_preview_html'        => "'''Tukwetondera! Tekisobose okukola ku nkyukakyuka z'okozewo kubanga data ekwata ku lutuula lwo evuddewo.'''<br />
<br />
''{{SITENAME}} esobozesa abantu okukola ku buwandike bwa yo obw'ennono obwa HTML.''<br />
''Olw'ensonga eyo tukisizza okulagako kw'ebigikyusidwako nga tugeza okwetaasa''<br />
''abakola enkyukakyuka ez'ekiyaaye nga bayitira mu JavaScript.''<br />
<br />
'''Bw'oba nga ddala ogenderera okukola enkyukakyuka wano mu bwesimbu, ddamu ogezeko.'''<br />
Ekyo bwe kitakola, sooka [[Special:UserLogout|oveemu]] mu wiki oryoke oddemu<br />
okugiyingira ogezeeko n'ate okukola enkyukakyuka zo.",
'token_suffix_mismatch'            => "'''Enkyukakyuka zo zigaanidwa olw'okuba nti puloguramu gy'okozesa etabuddetabudde'''<br />
'''obubonero obumenya mu bubaka obukakasa obugenderevu bw'omulimu ogwo.'''<br />
Okukyusakyusa kugaanidwa ebigambo ebiri ku lupapula lw'obadde okyusamu bireme nabyo okujjamu entabukatabuka.<br />
Kino kijjawo oluusi bw'obanga okozesa sisitemu ekusobozesa okulambula yintaneti ebikufaako ne bitayolesebwa<br /> abalala abagiriko, sisitemu eyo nga erimu ebitaatereera.",
'editing'                          => 'Kati okyusa $1',
'editingsection'                   => 'Okyusa $1 (kitundu)',
'editingcomment'                   => 'Okyusa $1 (kitundu kipya)',
'editconflict'                     => 'Ebikyusidwamu bireesewo okusobagana: $1',
'explainconflict'                  => "Waliwo omulala akyusizza mu lupapula luno nga okyalukolako.<br />
Ekitundu eky'ebiwandike ekisooka wano kikulaga ebigambo ebiruliko kakano.<br />
By'owandise byo biri mu kitundu eky'ebiwandike ekiddako.<br />
Ebigambo ebibyo on'obigatta mu ebyo ebiriwo ku lupapula kakano.<br />
Ebinaaba birabika mu kitundu eky'ebiwandike ekisooka w'on'onyigira ku<br />
\"{{int:savearticle}}\" '''bye byokka''' ebij'okukazibwa.",
'yourtext'                         => 'Ebigambo ebibyo',
'storedversion'                    => 'Ebiriwo kakano',
'nonunicodebrowser'                => "'''Kulabula: Kalambulaneti yo tekwatagana bulungi n'enkola ya unicode.'''<br />
Okuvvuunuka obuzibu buno osobole okukyusa mu mpapula, buli lw'on'owandikawo<br />
akabonero akatali ka ASCII kajjanga okuteekebwawo mu mpandika eya nengakkuminabbiri.",
'editingold'                       => "'''Kulabula: Olupapula lw'okyusamu luliko oluwandika lwa lwo olusinga luno obugya.'''<br />
By'okoze wano bw'on'obikaza enkyukakyuka endala zonna ezaakakolebwa abalala zijjakusaanawo.",
'yourdiff'                         => 'Ebikyuse',
'copyrightwarning'                 => "Genderera nti buli kyowandika muno mu {{SITENAME}} kibalibwa ng'ekifugibwa $2 (okuyiga ebisingawo, laba $1).
Obanga tewetegese okulaba by'owandise nga babikyusakyusa n'okubisaasaanya nga bwe balaba, tobiwandika muno.<br />
Tukwesiga nti by'owandika muno bibyo oba wabigya mu kya bonna oba awalala gye batalina bikugizo eby'obwa nannyini.
'''TOTEEKAMU EBIRIKO EBIKUGIZO EBY'OBWA NANNYINI NGA BA NYINI BYO TEBAKUWADDE LUKUSA!'''",
'copyrightwarning2'                => "Genderera nti buli kyowandika muno mu {{SITENAME}} abalala bayinza okubikyusa oba n'okubigiramu ddala. Obanga tewetegese okulaba by'owandise nga babikyusakyusa n'okubisaasaanya nga bwe balaba, tobiwandika muno.<br />
Tukwesiga nti by'owandika muno bibyo oba wabigya mu kya bonna oba awalala gye batalina bikugizo eby'obwa nannyini. (okuyiga ebisingawo, laba $1).
'''TOTEEKAMU EBIRIKO EBIKUGIZO EBY'OBWA NANNYINI NGA BA NYINI BYO TEBAKUWADDE LUKUSA!'''",
'longpageerror'                    => "'''Kulabula: By'owandise birimu kilobayiti $1.'''<br />
'''Ebisukka mu kilobayiti $2 tebikkirizibwa.'''<br />
Tekisobose kukaza by'owandise.",
'readonlywarning'                  => "'''Kulabula: Eggwanika lya data ku ssaawa eno terikkirizamu ebipya, kubanga balilongoosa.'''<br />
'''Tojjakusobola okukaza by'okola.'''<br />
Oyinza okukoppa by'owandise n'obitereka mu fayiro ku kompyuta yo osobole okubiteeka wano edda.<br />
<br />
Omuteesiteesi eyalisibye annyonyodde bwatyi: $1",
'protectedpagewarning'             => "'''Kulabula: Olupapula luno luliko ekikugizo ekikkiriza abalina endukusa z'obuteesiteesi bokka okulukyusamu.'''<br />
Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
'semiprotectedpagewarning'         => "'''Genderera: Olupapula luno luliko ekikugizo ekikkirizako ab'ewandisa ku wiki eno bokka okulukyusamu.'''<br />
Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
'cascadeprotectedwarning'          => "'''Kulabula:''' Olupapula luno luliko ekikugizo ekikkiriza abalina olukusa lw'obuteesiteesi bokka okulukyusamu.<br />
Kino kikoledwa olw'okuba nti lukozesebwa {{PLURAL:$1|olupapula oluliko ekikugizo ekiranda luna|empapula eziriko ebikugizo ebiranda zino}}:",
'titleprotectedwarning'            => "'''Kulabula: Olupapula luno luliko ekikugizo ekikwetaagisa [[Special:ListGroupRights|obuyinza obw'enjawulo]] okulukyusamu.'''<br />
Ekyasemba okuyingizibwa mu lukalala olw'ebifuddeyo lwa lwo bibino okwongera okukutangaaza ku nsonga eno:",
'templatesused'                    => 'Olupapula luno lukozesa {{PLURAL:$1|olutiba luno|ntiba zino}} :',
'templatesusedpreview'             => 'Okulagako kuno kweyambisa {{PLURAL:$1|olutiba luno|ntiba zino}}:',
'templatesusedsection'             => 'Ekitundu kino kyeyambisa {{PLURAL:$1|olutiba luno|ntiba zino}}:',
'template-protected'               => '(luno lusibidwa)',
'template-semiprotected'           => '(ebimu ku lupapula luno bisibidwa)',
'hiddencategories'                 => 'Olupapula luno lusangibwa mu {{PLURAL:$1|ttuluba erikise limu|matuluba amakise $1}}:',
'nocreatetitle'                    => 'Okukolawo empapula kuliko obukwakkulizo',
'nocreatetext'                     => "Ku {{SITENAME}} tosobola okukolawo empapula mpya nga tokozesa buyinza obw'obwamemba. Kati oyinza kugenda n'okyusamu olupapula olulala olwakolebwa dda, oba oyinza [[Special:UserLogin|okufuna obuyinza obw'obwamemba]].",
'nocreate-loggedin'                => 'Tolina buyinza bwa kukolawo empapula mpya.',
'sectioneditnotsupported-title'    => 'Okukyusa mu bitundu tekukkirizibwa',
'sectioneditnotsupported-text'     => 'Olupapula luno terukkiriza okukyusa mu bitundu.',
'permissionserrors'                => 'Wazzewo kiremya mu ndukusa zo',
'permissionserrorstext'            => "Kyoyagala okukola tekikukkirizibwa, olw'ensonga {{PLURAL:$1|eno|zino}}:",
'permissionserrorstext-withaction' => "Tokkirizibwa $2, olw'ensonga {{PLURAL:eno|zino|$1}}:",
'recreate-moveddeleted-warn'       => "'''Kulabula: Ogenda okuzzaawo olupapuka olwagyibwawo.'''

Okakasa nti kisaanira okuluzzaawo?
Ebifa ku kugyibwawo kw'olupapula luno bye bino:",
'moveddeleted-notice'              => "Olupapula luno lwagyibwawo.<br />
Ebiri mu lukalala olw'ebifa ku kulugyawo n'okulujjulula bibino okukutangaaza ku nsonga eno:",
'log-fulllog'                      => "Ndaga olukalala olw'ebifuddeyo mu bujjuvu",
'edit-hook-aborted'                => "Omulimu gwo gutegude emmanduso n'egukomya.<br />
Tewali kunnyonyola okusingawo.",
'edit-gone-missing'                => 'Olupapula tekisobose okulutuukanisa.<br />
Kirabika lwagyibwawo.',
'edit-conflict'                    => 'Ebikyusidwamu bireesewo okusobagana.',
'edit-no-change'                   => "Sisitemu ekubaze nga atalina ky'agikozeko, olw'okubanga ebiri ku lupapula obirese nga bwe wabisanze.",
'edit-already-exists'              => "Olupapula lw'ogeza okukolawo weruli, lwakolebwawo dda.<br />
Tekisobose kuddamu n'ate oulukolawo.",

# Parser/template warnings
'expensive-parserfunction-warning'        => "'''Kulabula:''' Olupapula luno luliko ebiragiro eby'ekikebera engoberera y'amateeka g'empandika ebizito ebiyitiridde obungi.<br />
<br />
Terukkirizibwa kubaako {{PLURAL:$2|kiragiro ky'ekibekebera ngoberera y'amateeka g'empandika ekisukka|biragiro by'ekikebera mpandika y'amateeka g'empandika ebisukka}} mu $2. Kakano ebiragiro ebyo luliko {{PLURAL:$1|kimu|$1}}.",
'expensive-parserfunction-category'       => "Empapula eziriko ebiragiro eby'ekikebera engoberera y'amateeka g'empandika ebizito ebiyitiridde obungi",
'post-expand-template-inclusion-warning'  => "'''Kulabula:''' Entiba ez'okunonebwa ziyitiridde obungi.<br />
Ezimu zijjakulebwayo.",
'post-expand-template-inclusion-category' => "Empapula eziriko entiba eziyitiridde obunene olw'ebinone bye zikozesa",
'post-expand-template-argument-warning'   => "'''Kulabula''' Olupapula luno luliko agumenti ey'omu lutiba nga amakulu gaamu bwe<br />
gawandikibwa mu bujjuvu ekivaamu kiyitirira obunene. Muyinz'okubaamu n'endala ez'engeri eno.<br />
Agumenti ezo sistemu tezikozesezza.",
'post-expand-template-argument-category'  => "Empapula eziriko agumenti ez'omu ntiba sisitemu z'etakozesezza",

# History pages
'viewpagelogs'           => "Kebera likooda ez'olupapula luno",
'currentrev'             => 'Ebiriwo kaakano',
'currentrev-asof'        => "Oluwandika lw'olupapula luno olusinga obupya, okuva nga $1",
'revisionasof'           => "Enfaanana y'olupapula luno ku saawa $1",
'previousrevision'       => '←Laba ebyasookawo bino',
'nextrevision'           => 'Oluwandika oluddako→',
'currentrevisionlink'    => 'Oluwandika oluliwo kakati',
'cur'                    => 'ebiriwo',
'last'                   => 'ebyasookawo bino',
'histlegend'             => "'''Ebyokugerageranizibwa:''' nyiga obutonnyeze ku likooda zoyagala okugerageranya olyoke onyige eppeesa erya 'Enter'<br />
oba ku gano agali ku lupapula luno.<br />
'''Ebigambo:''' (erw) = enjawulo ku ebiriwo, (eku) = enjawulo ku egikulembera, N = enkyukakyuka entono.",
'history-fieldset-title' => 'Mu nnanda nonamu ebyakolebwa:',
'histfirst'              => "Tandikira ku bisinga okuba eby'edda",
'histlast'               => 'Tandikira ku bisinga obupya',
'historysize'            => '({{PLURAL:$1|bayiti 1|bayiti $1}})',

# Revision feed
'history-feed-item-nocomment' => 'Bya $1, nga $2',

# Revision deletion
'rev-delundel'      => 'laga/kisa',
'rev-showdeleted'   => 'laga',
'revdelete-log'     => 'Nsonga:',
'revdel-restore'    => "tegeka ebiba biragibwa n'ebikisibwa",
'pagehist'          => "Ennanda y'olupapula luno",
'revdelete-content' => 'ebirimu',
'revdelete-uname'   => "ery'obwa memba",

# Merge log
'revertmerge' => 'Yawula ebigattidwa',

# Diffs
'history-title'           => 'Empandika eza "$1"',
'difference'              => "(Enjawulo mu mpandika ez'olupapula)",
'lineno'                  => 'Lunyiriri namba $1:',
'compareselectedversions' => 'Gerageranya likooda zenonze',
'editundo'                => 'julula enkyukakyuka',

# Search results
'searchresults'             => 'Noonyeza mu bizuulidwa',
'searchresults-title'       => 'Ebizuulidwa ku "$1"',
'searchresulttext'          => "Okumanya ebisingawo ku konoonya bintu ku {{SITENAME}}, kebera ku '[[{{MediaWiki:Helppage}}|{{int:help}}]]'.",
'searchsubtitle'            => 'Onoonyezza \'\'\'[[:$1]]\'\'\' ([[Special:Prefixindex/$1|empapula zonna ezitandika ne "$1"]]{{int:pipe-separator}}
[[Special:WhatLinksHere/$1|empapula zonna ezikuggusa ku "$1"]])',
'searchsubtitleinvalid'     => "Onoonyezza '''$1'''",
'toomanymatches'            => "Ebikwataganya by'onoonyezesazza biyitiridde obungi. Ky'onoonyezesa kikyusemu",
'titlematches'              => 'Empapula ezirina emitwe egyefaananyiriza guno',
'notitlematches'            => 'Tewali mpapula zirina mutwe guno',
'textmatches'               => "Empapula eziriko ebigambo by'onoonyezesezza",
'notextmatches'             => 'Tewali mpapula ziriko bigambo bino',
'prevn'                     => '{{PLURAL:$1|$1}} ezikulembedde zino',
'nextn'                     => '{{PLURAL:$1|$1}} eziddako',
'prevn-title'               => '{{PLURAL:$1|Ekizuulidwa $1 ekikulembera|Ebizuulidwa $1 ebikulembera}}',
'nextn-title'               => '{{PLURAL:$1|Ekizuulidwa $1 ekiddako|Ebizuulidwa $1 ebiddako}}',
'shown-title'               => 'Ndaga {{PLURAL:$1|ekizuulidwa|ebizuulidwa}} $1 ku buli lupapula',
'viewprevnext'              => 'Laga ($1 {{int:pipe-separator}} $2) ($3).',
'searchmenu-legend'         => 'Kyusamu ennoonya',
'searchmenu-exists'         => "'''Olupapula \"[[:\$1]]\" gyeruli ku wiki eno.'''",
'searchmenu-new'            => "'''Oba oyagala, olupapula \"[[:\$1]]\" gwe osobola okulukolawo ku wiki eno.'''",
'searchhelp-url'            => 'Help:Endagiriro',
'searchmenu-prefix'         => '[[Special:PrefixIndex/$1|Kebera mu mpapula eziriko akatandikwa kano]]',
'searchprofile-articles'    => "Empapula ez'ensonga",
'searchprofile-project'     => "Empapula eziriko obuyambi n'eza Kawefube",
'searchprofile-images'      => "Mediya ey'ekintabuli - Bifaananyi, Vidiyo n'ebiWulirizibwa",
'search-result-size'        => '$1 ({{PLURAL:$2|kigambo 1 | bigambo $2}})',
'search-redirect'           => "(olupapula '$1' lukuggusiza wano)",
'search-section'            => '(ekitundu ekya $1)',
'search-suggest'            => 'Obadde onoonya $1 ?',
'search-interwiki-caption'  => "Pulojekiti ezikolagana n'eno",
'search-interwiki-default'  => 'ebizuulidwa ku $1:',
'search-interwiki-more'     => '(ebikyaliyo)',
'search-mwsuggest-enabled'  => 'mpeeraako amagezi',
'search-mwsuggest-disabled' => "sisitemu ereme okuteebereza ky'onoonya",
'nonefound'                 => "'''Wekkaanye''': Okunoonya kuno kukoma mu makuŋaanyizo amalondemu okugyako nga okulagidde okweyonera awalala.
W'owandikira by'onoonya bw'osoosawo akagambo ''all:'', okunoonya kubuna Wikipediya yonna. Bw'obanga olina ekkuŋaanyizo limu lyokka lyoyagala okunoonyezamu, soosawo erinnya lyalyo w'owandikira by'onoonya.",
'powersearch'               => 'Noonya mu ngeri esunsula',
'powersearch-legend'        => 'Noonya mu ngeri esunsula',
'powersearch-ns'            => 'Noonyeza mu makuŋaaniro gano:',
'powersearch-redir'         => "Laga n'empapula ezikutwalabutwazi ku zinnaazo",
'powersearch-field'         => 'Nnoonyeza',

# Preferences page
'preferences'               => 'Enteekateeka yange',
'mypreferences'             => 'Enteekateeka yange',
'skin-preview'              => 'Kulozzako',
'prefs-personal'            => 'Ebikufaako',
'prefs-resetpass'           => 'Kyusa ekigambo ekikuumi',
'prefs-email'               => 'Enteekateeka eza E-mail',
'prefs-rendering'           => 'Endabika',
'saveprefs'                 => 'Bino bikaze',
'resetprefs'                => 'Gyawo enkyukakyuka ze sinnakaza',
'restoreprefs'              => 'Zawo enteekateeka zi nansangwawo',
'prefs-editing'             => 'Kukyusa',
'searchresultshead'         => 'Noonya',
'savedprefs'                => 'Enteekateeka yo ekazidwa.',
'timezonelegend'            => 'Ssaawa za mu:',
'localtime'                 => "Ssaawa za w'oli:",
'timezoneuseserverdefault'  => 'Kozesa ssaawa sistemu ze yerondera',
'timezoneuseoffset'         => 'Ndala (tegeka enjawulo mu budde)',
'timezoneoffset'            => 'Njawulo mu budde¹:',
'servertime'                => 'Ssaawa ya sisitemu:',
'guesstimezone'             => 'Kalambulanetti etegeke obudde',
'timezoneregion-africa'     => 'Afirika',
'timezoneregion-america'    => 'Amerika',
'timezoneregion-antarctica' => 'Antakitika',
'timezoneregion-arctic'     => 'Akitiki',
'timezoneregion-asia'       => 'Ezya',
'timezoneregion-atlantic'   => 'Liyanja Atalantika',
'timezoneregion-australia'  => 'Awusitureliya',
'timezoneregion-europe'     => 'Bulaaya',
'timezoneregion-indian'     => 'Liyanja ya Buyindi',
'timezoneregion-pacific'    => 'Liyanja Kirimulaala',
'allowemail'                => 'Kkiriza bamemba abalala okukusindikira e-mail',
'prefs-searchoptions'       => 'Enteekateeka ezifuga okunoonya',
'prefs-namespaces'          => 'Makuŋaanyizo',
'username'                  => "Ery'obwa memba:",
'yourlanguage'              => 'Lulimi lwo:',
'yournick'                  => 'Empaako yo (ssi ya tteeka):',
'prefs-help-email'          => "Okuwayo E-mail yo ssi kya tteeka, naye yetaagisibwa bw'obanga werabide ekigambo kyo ekikuumi - basobole okukusindikira ekipya.

Osobola okusalawo okuba nga ab'etaaga okukutuukirira bayitira ku nfo yo ey'obwa memba oba olupapula lwo olwa 'yogera nange' nga ggwe tewetaaze kulaga bikufaako.",

# User rights
'editinguser'       => "Okyusa ndukusa za memba '''[[User:$1|$1]]''' ([[User talk:$1|{{int:talkpagelinktext}}]] {{int:pipe-separator}} [[Special:Contributions/$1|{{int:contribslink}}]])",
'userrights-reason' => 'Nsonga:',

# Groups
'group-sysop' => 'Abateesiteesi',

'grouppage-sysop' => '{{ns:project}}:Abateesiteesi',

# User rights log
'rightslog' => "Olukalala lw'ebifudeyo ku by'endukusa za bamemba",

# Associated actions - in the sentence "You do not have permission to X"
'action-edit' => 'olupapula luno okulukolamu nkyukakyuka',

# Recent changes
'nchanges'                       => '{{PLURAL:$1|Olukyukakyuka|Nkyukakyuka}} $1',
'recentchanges'                  => 'Ebyakakyusibwa',
'recentchanges-legend'           => "Awategekerwa endaga y'ebyakakyusibwa",
'recentchangestext'              => "Goberera enkyukakyuka empya ez'oku lupapula luno",
'recentchanges-feed-description' => "Kozesa omukutu guno okugoberera enkyukakyuka empya ez'oku wiki",
'rcnote'                         => "Wano olaba {{PLURAL:$1|olukyukakyuka '''1''' olukoledwawo|enkyukakyuka '''$1''' ezikoledwawo}} mu {{PLURAL:$2|lunaku olwakayita|naku '''$2''' ezaakayita}}. Bino byategeerese ku ssaawa $5 nga $4.",
'rclistfrom'                     => 'Laga enkyukakyuka empya ezikoledwa okuva $1',
'rcshowhideminor'                => '$1 nkyukakyuka ntono',
'rcshowhidebots'                 => '$1 ebya bboti',
'rcshowhideliu'                  => '$1 ebya bamemba abali ku wiki ku saawa eno',
'rcshowhideanons'                => "$1 eby'abakola ng'abat'eyanjude",
'rcshowhidemine'                 => '$1 nze byenkoze',
'rclinks'                        => 'Ndaga enkyukakyuka $1 ezikoledwa mu nnaku $2 ezaakayita<br />$3',
'diff'                           => 'enjawulo',
'hist'                           => 'ennanda',
'hide'                           => 'Kisa',
'show'                           => 'Laga',
'minoreditletter'                => 'n',
'newpageletter'                  => 'Lupya!',
'boteditletter'                  => 'b',
'rc-enhanced-expand'             => 'Birage mu bujjuvu (kino kyetaagisa JavaScript)',
'rc-enhanced-hide'               => 'Birage mu bumpi',

# Recent changes linked
'recentchangeslinked'          => 'Ebikyusiddwa ebyekuusa ku lupapula luno',
'recentchangeslinked-feed'     => 'Ebikyusiddwa ebyekuusa ku lupapula luno',
'recentchangeslinked-toolbox'  => 'Ebikyusiddwa ebyekuusa ku lupapula luno',
'recentchangeslinked-title'    => 'Enkyukakyuka ezikwatagana ne "$1"',
'recentchangeslinked-noresult' => 'Empapula eziriko enyunzi tewali lukyuse mu kiseera kino.',
'recentchangeslinked-summary'  => "Olulpapula olw'enjawulo luno luliko olukalala lw'ebikyuse ku mpapula eziriko enyunzi ezigguka ku lw'obadde otunuulira. Ebiwandikidwa mu '''nukuta enziggumivu''' biri ku [[Special:Watchlist|mpapula z'ogoberera]].",
'recentchangeslinked-page'     => 'Lupapula:',
'recentchangeslinked-to'       => "Nonamu eby'empapula ezikuggusa ku luno zokka",

# Upload
'upload'        => 'Teekayo fayiro',
'uploadlogpage' => 'Likooda eya fayiro eziteekedwa ku wiki',
'uploadedimage' => 'yateekayo "[[$1]]"',

# Special:ListFiles
'listfiles_user' => 'Memba',

# File description page
'file-anchor-link'          => 'Fayiro',
'filehist'                  => 'Ebyafaayo ebya fayiro eno',
'filehist-help'             => "Bw'onyiga ku nnaku n'essaawa, ojjakulaba fayiro nga bwe yali efaanana ku kiseera ekyo.",
'filehist-current'          => 'oluwandika oluliwo kakano',
'filehist-datetime'         => "Ennaku n'obudde",
'filehist-thumb'            => 'Kulingiza',
'filehist-thumbtext'        => 'Lingiza oluwandika olwakolebwa nga $1',
'filehist-user'             => 'Eyakiteekawo',
'filehist-dimensions'       => "Obuwanvu n'obugazi bwakyo",
'filehist-filesize'         => 'Obunene bwa fayiro eno',
'filehist-comment'          => "Okulw'ogerako",
'imagelinks'                => 'Empapula eziriko enyunzi ezigguka ku kifaananyi kino',
'linkstoimage'              => '{{PLURAL:olupapula $1 olukuggusa ku fayiro eno lwe|Empapula $1 ezikuggusa ku fayiro eno ze}}:',
'nolinkstoimage'            => 'Tewali mpapula ziriko nyunzi ezigguka ku fayiro eno.',
'sharedupload'              => "Fayiro eno, ey'omu $1, y'emu esobola okuba nga empapula ez'omu pulojekiti endala zigikozesa",
'uploadnewversion-linktext' => 'Teekayo oluwandika lwa fayiro eno olupya',

# File deletion
'filedelete-comment' => 'Ekigyisizzawo fayiro:',

# Random page
'randompage' => 'Nondera olupapula muwawa',

# Statistics
'statistics' => 'Ebibalidwa',

# Miscellaneous special pages
'nbytes'            => '{{PLURAL:$1|bayiti|bayiti}} $1',
'ncategories'       => '$1 {{PLURAL:$1|ttuluba|matuluba}}',
'nmembers'          => '{{PLURAL:$1|memba|bamemba}} $1',
'prefixindex'       => 'Empapula eziriko akatandikwa ku manya gaazo',
'newpages'          => 'Empapula empya',
'newpages-username' => "Ery'obwa memba:",
'move'              => 'Simbuliza',
'movethispage'      => "Kyusa erinnya ly'olupapula luno",
'pager-newer-n'     => '{{PLURAL:$1|ekisingawo obupya 1|ebisingawo obupya $1}}',
'pager-older-n'     => '{{PLURAL:$1|ekyasooka bino 1|ebyasooka bino $1}}',

# Book sources
'booksources'               => 'Ebitabo ebijulizidwa',
'booksources-search-legend' => "Noonya ebitabo eby'okujuliza",
'booksources-go'            => 'Nona',

# Special:Log
'specialloguserlabel' => 'Memba:',
'log'                 => "Empapula ez'ebyafaayo eby'emirimu egitaligimu",

# Special:AllPages
'allpages'          => 'Empapula zonna',
'alphaindexline'    => 'okuva ku $1 kutuuka ku $2',
'nextpage'          => 'Dda ku luddirira luno ($1)',
'prevpage'          => 'Dda ku lukulembera luno ($1)',
'allpagesfrom'      => 'Laga empapula okuva ku:',
'allpagesto'        => 'Laga empapula okutuuka ku:',
'allarticles'       => 'Empapula zonna',
'allinnamespace'    => 'Empapula zonna (mu kkunngaanizo erya $1)',
'allnotinnamespace' => 'Empapula zonna (ezitali mu kkunngaanizo erya $1)',
'allpagessubmit'    => 'Nona',
'allpagesprefix'    => 'Ndaga empapula eziriko akatandikwa kano:',

# Special:Categories
'categories' => 'Amatuluba',

# Special:LinkSearch
'linksearch'    => 'Ennyunzi eziggukira wabweru wa Wikipediya',
'linksearch-ns' => 'Kuŋaanyizo:',
'linksearch-ok' => 'Noonya',

# Special:Log/newusers
'newuserlogpage'          => "Olukalala olw'ebifudeyo mu kukolawo akawunti empya",
'newuserlog-create-entry' => 'Akawunti empya',

# Special:ListGroupRights
'listgrouprights-members' => '(lukalala lwa bamemba)',

# E-mail user
'emailuser' => 'Memba ono musindikire e-mail',

# Watchlist
'watchlist'         => 'Empapula zengoberera',
'mywatchlist'       => 'Empapula zengoberera',
'addedwatch'        => "Kigattiddwa ku by'ogoberera",
'addedwatchtext'    => 'Olupapula "[[:$1]]" kati luli mu [[Special:Watchlist|by\'ogoberera]].
Buli olupapula olwo oba olw\'emboozi lwalwo lwe binaakyusibwamu, enkyukakyuka ezo
zijjakulabika wano. Era erinnya lyalwo mu [[Special:RecentChanges|lukalala olw\'ebyakakyusibwa]]
lijja okuba mu nukuta enziggumivu oyanguyirwe okuliraba.

Bw\'oba oyagala okulekerawo okulugoberera, nyiga ku kigambo "Suula" awo ku bbali.',
'removedwatch'      => "Lugyidwamu mu lukalala lw'empapula z'ogoberera",
'removedwatchtext'  => 'Olupapula "[[:$1]]" lugyidwamu mu [[Special:Watchlist|lukalala lw\'empapula z\'ogoberera]].',
'watch'             => 'Goberera olupapula luno',
'watchthispage'     => 'Goberera olupapula luno',
'unwatch'           => 'Lekerawo okugoberera olupapula luno',
'watchlist-details' => "Olina {{PLURAL:$1|olupapula $1|empapula $1}} z'ogoberera, nga tobalideko n'eza yogera-nange.",
'wlshowlast'        => "Ndaga ez'omu ssaawa $1 n'ennaku $2 eziyise oba $3",
'watchlist-options' => "Enteetakeeka y'endaga ya mpapula zengoberera",

# Displayed when you click the "watch" button and it is in the process of watching
'watching'   => 'Kikolebwako...',
'unwatching' => 'Kikolebwako...',

# Delete
'deletepage'            => 'Gyawo olupapula',
'confirm'               => 'Kakasa',
'confirmdeletetext'     => "Ogenda okugyawo olupapula n'ennanda ya lwo yonna.

Kakasa nti kino ky'oyagala, era nti otegeera bye kinaaleetawo, era nti kikkirizigana [[{{MediaWiki:Policy-url}}|n'enkola ya MediaWiki]].",
'actioncomplete'        => 'Kiwedde',
'deletedtext'           => 'Olupapula "<nowiki>$1</nowiki>" lugyidwawo.

Kebera olukalala $2 okumanya ebifa ku byakagyibwawo.',
'deletedarticle'        => 'olupapula olwa "[[$1]]" lugyidwawo',
'dellogpage'            => 'Ebigyidwawo',
'deletecomment'         => 'Nsonga:',
'deleteotherreason'     => 'Nsonga ndala:',
'deletereasonotherlist' => 'Nsonga ndala',

# Rollback
'rollback'       => 'Jjululako ku bikyusidwamu',
'rollback_short' => 'Jjulula nkyukakyuka',
'rollbacklink'   => 'julula nkyukakyuka',
'rollbackfailed' => 'Okujjulula tekusobose',

# Protect
'protectlogpage'              => "Olukalala lw'ebifa ku mpapula ezisibidwa",
'protectedarticle'            => 'olupapula "[[$1]]" lusibidwa',
'modifiedarticleprotection'   => 'okusibibwa kwa "[[$1]]" kukyusidwa',
'protectcomment'              => 'Nsonga:',
'protectexpiry'               => 'Kukoma nga:',
'protect_expiry_invalid'      => "Ekkomo ery'okusibibwa terikkizidwa.",
'protect_expiry_old'          => "Ekkomo ery'okusibibwa liri ku budde obwayita.",
'protect-text'                => "Wano w'osobolera okukebera n'okukyusa okusibibwa kw'olupapula '''<nowiki>$1</nowiki>'''.",
'protect-locked-access'       => "Akawunti yo tekuwa lukusa kukyusa okusibibwa kw'olupapula luno.

Eno y'enteekateeka ey'olupapula '''$1''':",
'protect-cascadeon'           => "Okukyusa olupapula luno kuliko ebikugizo, olw'okubanga lweyazikidwa {{PLURAL:$1|olupapula oluliko|mpapula eziriko}} okusibibwa okulanda.

Oyinz'okukyusa okusibibwa kw'olupapula luno, naye tekijjakukyusa ebikugizo ebivudde ku kusibibwa okulanda.",
'protect-default'             => 'Kkiriza buli memba',
'protect-fallback'            => 'Kyetaagise obuyinza obwa "$1"',
'protect-level-autoconfirmed' => "Gaana bamemba abapya n'abatali bamemba",
'protect-level-sysop'         => 'Bateesiteesi bokka',
'protect-summary-cascade'     => 'kulanda',
'protect-expiring'            => 'kukoma nga $1 (UTC)',
'protect-cascade'             => "Okusiba kuzingeremu n'empapula luno ze lweyazika (okusiba okulanda)",
'protect-cantedit'            => "Tosobola kukyusa okusibibwa kw'olupapula luno kubanga tolina lukusa lwa kulukyusako kyonna.",
'protect-expiry-options'      => 'saawa 2:2 hours,lunaku 1:1 day,nnaku 3:3 days,sande 1:1 week,sande 2:2 weeks,mwezi 1:1 month,myezi 3:3 months,myezi 6:6 months,mwaka 1:1 year,okutali kkomo:infinite',
'restriction-type'            => 'Olukusa:',
'restriction-level'           => "Ddaala ly'okusibibwa:",

# Restrictions (nouns)
'restriction-edit' => 'Kyusa',
'restriction-move' => 'Simbuliza',

# Undelete
'undeletebtn'            => 'Luzzewo',
'undeletelink'           => 'lukebere/luzzewo',
'undeletecomment'        => 'Nsonga:',
'undeletedarticle'       => '"[[$1]]" luzzidwawo',
'undelete-search-submit' => 'Noonya',

# Namespace form on various pages
'namespace'      => 'Kuŋaanyizo:',
'invert'         => 'Kola ku byonna ebitali ekyo ekirondedwa',
'blanknamespace' => '(Kuŋaanyizo lya byonna)',

# Contributions
'contributions'       => 'Memba byakozeyo ku wiki',
'contributions-title' => '$1 byawaddeyo',
'mycontris'           => 'Byempaddeyo',
'contribsub2'         => '$1 ($2)',
'uctop'               => '(enkyukakyuka esembye ku lupapula)',
'month'               => "Mu mwezi (n'egyakulembera):",
'year'                => "Mu mwaka (n'egyakulembera):",

'sp-contributions-newbies'  => "Ndaga ebikoledwa abaak'egata ku Wiki byokka",
'sp-contributions-blocklog' => 'Ebifa ku bagaanidwa',
'sp-contributions-talk'     => 'yogera nange',
'sp-contributions-search'   => 'Kebera bye bawaddeyo',
'sp-contributions-username' => "Endagiriro eya IP oba linnya ly'obwa memba:",
'sp-contributions-submit'   => 'Noonya',

# What links here
'whatlinkshere'            => 'Empapula ezikuggusa ku luno',
'whatlinkshere-title'      => 'Empapula eziriko enyunzi ezigguka ku $1',
'whatlinkshere-page'       => 'Lupapula:',
'linkshere'                => "Zino z'empapula eziriko enyunzi ezigguka ku '''[[:$1]]''':",
'nolinkshere'              => "Tewali mpapula eziriko enyunzi ezigguka ku '''[[:$1]]'''.",
'isredirect'               => 'lupapula olukutwalabutwazi ku lunnaalwo',
'istemplate'               => 'kitundu ekyeyazike',
'isimage'                  => 'lukozesa ekifaananyi kino',
'whatlinkshere-prev'       => '{{PLURAL:$1|olukulembera|$1 ezikulembera}}',
'whatlinkshere-next'       => '{{PLURAL:$1|oluddako|$1 eziddako}}',
'whatlinkshere-links'      => '← Empapula eziriko enyunzi ezigguka ku luno',
'whatlinkshere-hideredirs' => '$1 mpapula ezikutwalabutwazi ku zinnaazo',
'whatlinkshere-hidetrans'  => '$1 ebitundu ebyeyazike',
'whatlinkshere-hidelinks'  => '$1 nyunzi',
'whatlinkshere-filters'    => 'Ensunsula',

# Block/unblock
'blockip'                  => 'Gaana memba okuwandika',
'ipboptions'               => 'saawa 2:2 hours,lunaku 1:1 day,nnaku 3:3 days,sande 1:1 week,sande 2:2 weeks,mwezi 1:1 month,myezi 3:3 months,myezi 6:6 months,mwaka 1:1 year,okutali kkomo:infinite',
'blockipsuccesssub'        => 'Memba agaaniddwa okuwandika',
'ipblocklist'              => 'Abagaanidwa',
'ipblocklist-submit'       => 'Noonya',
'blocklink'                => 'Ono agaanibwe okuwandika',
'unblocklink'              => 'kkiriza memba okuwandika',
'change-blocklink'         => 'kyusa okugaanibwa',
'contribslink'             => 'byawaddeyo',
'blocklogpage'             => 'Abagaanidwa',
'blocklogentry'            => '[[$1]] agaanidwa. Obuyinza bumuddizibwa ku $2 $3',
'unblocklogentry'          => '$1 akkirizidwa okuddamu okuwandika',
'block-log-flags-nocreate' => 'okukolawo akawunti empya kusibidwa',

# Move page
'move-page-legend' => 'Simbuliza olupapula luno',
'movepagetext'     => "Foomu eno ekyusa erinnya ly'olupapula era n'ekyusa n'olukalala lw'ebyafaayo lwa lwo lwogere ku linnya ppya.

Wajjakukolebwawo n'olupapula olulina erinnya kkadde nga lwo lukutwalabutwazi ku lupapula olukyusidw'erinnya.
Osobola okulagira sisitemu n'ekukyusiza empapula endala ezikutwalabutwazi ku linnya kkadde, zikutwalenga ku linnya ppya.

Bw'oba ng'ekyo toyagadde ekikukolere, laba nti onoonya n'ogolola empapula [[Special:DoubleRedirects|'''ezikutwalabutwazi ku ndala ng'ate ne'yo eyagala okukutwalabutwazi ku ndala''']] n'ezo [[Special:BrokenRedirects|'''ezikutwalabutwazi ku ndala etaliwo''']] zonna ezireetedwawo okusimbuliza kw'okoze.

Buvunaanyizibwa bwo okulaba nti enyunzi zonna zisigala nga ziggukira gye wali ogenderedde.

Genderera nti olupapula terujjakukyusibwa linnya ssinga waba nga waliwo olupapula olulala olulina erinnya ly'oyagala okukozesa, okugyako nga olwo lwereere oba nga lukutwalabutwazi ku lulala era nga teruliko olukalala lw'ebyafayo.
Kino kitegeeza nti bw'okola nsobi mu kukyusa linnya, oyinza okuluzzayo ku linnya kkadde, naye tosobola okubuutikira olupapula olusangidwawo.

'''Kulabula!'''

Olupapula lw'oyagala okusimbuliza luyinz'okuba nga lujjumbirwa bangi. Okulukyusa erinnya kiyinz'okubagwakobugwi nga tebakiriindiridde. Sooka weroowoze nnyo olabe nti ebiyinz'okuva mu kikolwa kino obitegeera era tebireetewo obukosefu okuteetaagisibwa.",
'movepagetalktext' => "Olupapula olwa yogera nange nalwo sisitemu ejjakulukyusizaako '''okugyako nga:'''

*Ku linnya ppya wasangibwawo olupapula lya yogera nange olulala olutali lwereere, oba

*Ogyamu akali mu kabokisi akalagira sistemu okukikola.


Ekimu ku ebyo ebibiri bwe kibawo, olwo gwe oba olina okwekyusiza olwa yogera nange.",
'movearticle'      => 'Simbuliza olupapula luno',
'newtitle'         => 'Luyitibwe:',
'move-watch'       => 'Goberera olupapula luno',
'movepagebtn'      => 'Lusimbulize',
'pagemovedsub'     => 'Olupapula lusimbulizidwa',
'movepage-moved'   => '\'\'\'"$1" kati luyitibwa "$2"\'\'\'',
'articleexists'    => 'Erinnya eryo waliwo olupapula olulala olulirina. Oba ssi ekyo, olonze erinnya eritakkirizibwa.
Londayo eddala.',
'talkexists'       => "'''Olupapula lukyusidwa erinnya. Wabula tekisobose okukyusizako ne yogera nange, olwokubanga wasangidwawo yogera nange endala ku linnya eppya.
Yogera nange gwe olina okugyegattira ku eyo esangidwawo.'''",
'movedto'          => 'kati lutumidwa',
'movetalk'         => "N'olupapula olwa yogera nange lwakwo lusimbulize",
'1movedto2'        => 'olupapula [[$1]] lukyusidwa luyitibwe [[$2]]',
'1movedto2_redir'  => 'olupapula [[$1]] kati lukutwalabutwazi ku [[$2]], ebyalulingako kaakano gye bisangibwa',
'movelogpage'      => 'Ebikyusidwa manya',
'movereason'       => 'Nsonga:',
'revertmove'       => 'zaawo erinya ekkadde',

# Export
'export' => 'Okusomosa mpapula',

# Namespace 8 related
'allmessages'                   => 'Bubaka bwa sisitemu',
'allmessagesname'               => 'Erinnya',
'allmessagesdefault'            => 'Ebigambo ebya bulijjo',
'allmessagescurrent'            => 'Ebiriwo kakano',
'allmessagestext'               => "Luno lwe lukalala olw'obubaka obwa sisitemu obw'omu kkuŋŋaanizo erya MediaWiki.

Ob'oyagala okuyamba ku kuvvuunula eby'omu MediaWiki yonna, kebera ku [http://www.mediawiki.org/wiki/Localisation MediaWiki Localisation] ne [http://translatewiki.net translatewiki.net].",
'allmessages-filter-legend'     => 'Ensunsula',
'allmessages-filter'            => 'Londamu:',
'allmessages-filter-unmodified' => 'Ebitannakyusibwamu',
'allmessages-filter-all'        => 'Byonna',
'allmessages-filter-modified'   => 'Ebikyusidwamu',
'allmessages-prefix'            => 'Londa ebiriko akatandikwa ka:',
'allmessages-language'          => 'Lulimi:',
'allmessages-filter-submit'     => 'Nona',

# Thumbnails
'thumbnail-more'  => 'Gejjesa akafaanayi',
'thumbnail_error' => 'Akafaananyi kazeeko kiremya: $1',

# Tooltip help for the actions
'tooltip-pt-userpage'             => "Nyiga wano okutuuka ku nfo yo ey'obwa memba",
'tooltip-pt-mytalk'               => 'Bamemba bwe bakusindikira obubaka, bulabikira wano',
'tooltip-pt-preferences'          => "Nyiga wano ob'oyagala okukyusaamu engeri wiki gy'ekulabikira ne bw'ekukoleramu",
'tooltip-pt-watchlist'            => "Nyiga wano okulaba olukalala lw'empapula z'ogeberera",
'tooltip-pt-mycontris'            => 'Nyiga wano okulaba olukalala lwa bye wakakolawo ku wiki eno',
'tooltip-pt-login'                => "Nyiga wano osobole okulambula wiki eno ng'okozesa buyinza obwa memba",
'tooltip-pt-logout'               => 'Nyiga wano oba oyagala okulambula wiki eno nga tokozesa buyinza obwa memba',
'tooltip-ca-talk'                 => "Wano osobola okusoma ebirowozo abantu byebawaddeyo ku lupapula luno era naawe n'owayo ebibyo",
'tooltip-ca-edit'                 => "Nyiga wano ob'oyagala okukyusakyusaamu lupapula luno. Bw'omala okuwandika enkyukakyuka zo, nyiga ku kapeesa aka 'Sooka ondageko' ozikebere nga tonnazikariza ddala kulabibwa bonna.",
'tooltip-ca-addsection'           => 'Nyiga wano oba oyagala okuwayo ekirowozo ku kintu kipya mu kuwanyisigana ebirowozo kuno.',
'tooltip-ca-viewsource'           => "Olupapula luno lusibidwa - tosobola okulukyusa, naye okkirizibwa okulaba obulambike obw'ennono bwalwo.",
'tooltip-ca-history'              => "Bw'onyiga wano, olaba empandika z'olupapula luno ezaasookawo",
'tooltip-ca-protect'              => 'Siba olupapula luno',
'tooltip-ca-delete'               => "Nyiga wano ob'oyagala okugyawo olupapula luno",
'tooltip-ca-move'                 => "Kyusa erinnya ly'olupapula luno",
'tooltip-ca-watch'                => "Olupapula luno luteekebwe ku lukalala lw'ezo z'ogeberera enkyukakyuka ezizikolebwako",
'tooltip-ca-unwatch'              => "Nyiga wano ob'oyagala okulekerawo okutegeezebwanga enkyukakyuka mu lupapula luno",
'tooltip-search'                  => 'Noonyeza ku {{SITENAME}}',
'tooltip-search-go'               => "Bw'onyiga wano kinonayo olupapula olutumidwa ekigambo ky'owandise kyennyini, bwe luba nga gyeluli",
'tooltip-search-fulltext'         => "bw'onyiga wano kinoonya empapula zonna mu Wikipediya ezirimu ebigambo by'owandise",
'tooltip-n-mainpage'              => "Nyiga wano ob'oyagala okukebera olupapula olusooka",
'tooltip-n-mainpage-description'  => 'Genda ku lupapula olusookerwako',
'tooltip-n-portal'                => "Ebikutangaaza ku kawefube wa Wiki eno n'engeri naawe mw'osobolera okubyenyigiramu",
'tooltip-n-currentevents'         => 'Nyiga wano oba oyagala okuyiga ebisingawo ku bibindabinda',
'tooltip-n-recentchanges'         => "Nyiga wano okulaba olukalala lw'ebyakakyusibwamu ku wiki eno",
'tooltip-n-randompage'            => 'Nnondera olupapula lwemba nkebera',
'tooltip-n-help'                  => 'Ebikutangaaza ku nkola ya Wiki eno',
'tooltip-t-whatlinkshere'         => "Nyiga wano okulaba empapula ez'oku wiki zonna eziriko enyunzi ezikuggusa ku luno",
'tooltip-t-recentchangeslinked'   => "Enkyukakyuka mpya ku mpapula z'osobola okuggukako okuva ku luno",
'tooltip-feed-rss'                => "Nyiga wano okulaba omukutu gw'amawulire agafa ku lupapula luno ogw'ekika kya RSS",
'tooltip-feed-atom'               => "Nyiga wano okulaba omukutu gw'amawulire agafa ku lupapula luno ogw'ekika kya Atom",
'tooltip-t-contributions'         => "Nyiga wano ob'oyagala okumanya memba ono by'akozeyo ku wiki eno",
'tooltip-t-emailuser'             => "Nyiga wano ob'oyagala memba ono okumusindikira e-mail",
'tooltip-t-upload'                => "Nyiga wano ob'oyagala okuteekayo fayiro ku wiki eno",
'tooltip-t-specialpages'          => "Nyiga wano okulaba olukalala olw'empapula ez'enjawulo zonna",
'tooltip-t-print'                 => "Bw'onyiga wano olupapula luno lwetereeza mu ngeri erulabisa obulungi nga lukubisidwa ku kyapa (pulinta)",
'tooltip-t-permalink'             => "Kolawo ennyunzi egguka ku luwandika luno olw'olupapula luno",
'tooltip-ca-nstab-main'           => 'Nyiga wano osome olupapula luno',
'tooltip-ca-nstab-user'           => "Nyiga wano ob'oyagala okulaba enfo ya memba",
'tooltip-ca-nstab-special'        => 'Luno lupapula olwawule, gwe tosobola okulukolako enkuyukakyuka',
'tooltip-ca-nstab-project'        => "Nyiga wano ob'oyagala okukebera ekkuŋaanizo erya kawefube ono",
'tooltip-ca-nstab-image'          => 'Nyiga wano okugenda ku lupapula oluliko ekifaananyi',
'tooltip-ca-nstab-template'       => 'Nyiga wano okukebera olutiba',
'tooltip-ca-nstab-category'       => "Nyiga wano ob'oyagala okulaba olupapula olw'ettuluba lino",
'tooltip-minoredit'               => "Nyiga wano ob'oyagala nkyukakyuka z'ovakukola zirambibwe nti ntono",
'tooltip-save'                    => "Kaza enkyukakyuka z'okoze",
'tooltip-preview'                 => "Nyiga wano okulaba enkyukakyuka zo bwe zinaalabika. Kirungi okukola kino nga tonnakaza by'okoze - kikuyamba kukwata nsobi!",
'tooltip-diff'                    => "Nyiga wano okulaba by'okoze bwe byawukana n'ebisangidwawo",
'tooltip-compareselectedversions' => "Nyiga wano ob'oyagala okulaba enjawulo wakati w'empandika ez'olupapula luno z'olonze.",
'tooltip-watch'                   => "Nyiga wano olupapula luno ob'oyagala okutegeezebwanga buli ebirukyusibwako",
'tooltip-rollback'                => '"Julula nkyukakyuka" kigyamu enkyukakyuka ez\'eyasemba okukola ku lupapula luno',
'tooltip-undo'                    => "Bwonyiga \"Julula\", kijjulula enkyukakyuka z'okoze wano ne kikulagako by'obadde okolako bwe binaalabika nga bikazidwa. Era oba osobola n'okuwandikawo ebinnyonyola enkyukakyuka zo.",

# Attribution
'anonymous'        => "{{PLURAL:$1|akoze ku {{SITENAME}} nga teyeyanjudde|abakoze ku {{SITENAME}} nga teb'eyanjudde}}",
'siteuser'         => '{{SITENAME}} memba $1',
'lastmodifiedatby' => 'Olupapula luno lwasemba okukyusibwamu $3 ku saawa $2, nga $1',
'othercontribs'    => 'nga ayongereza ku byakolebwa $1',
'siteusers'        => '{{PLURAL:$2|memba wa|bamemba ba}} {{SITENAME}} $1',
'creditspage'      => 'Abakoze ku lupapula luno',

# Browsing diffs
'previousdiff' => '← Laba enjawulo ezaakulembera zino',
'nextdiff'     => 'Enkyukakyuka ezaddako okukolebwa→',

# Media information
'file-info-size'       => '(pikseli $1 ku $2 , bunene bwa fayiro: $3, kika kya MIME: $4)',
'file-nohires'         => '<small>Tewali kisingako wano.</small>',
'svg-long-desc'        => '(Fayiro ya kika  kya SVG, ya pikselo $1 ku $2 awamu, ya obunene bwa: $3)',
'show-big-image'       => 'Laga ekifaananyi ekijjuvu',
'show-big-image-thumb' => '<small>Okulagako kuno kwa pikiseli: $1 ku $2</small>',

# Special:NewFiles
'ilsubmit' => 'Noonya',

# Bad image list
'bad_image_list' => 'Empandika entuufu:

Ennyiriri ezikola lukalala (ezitandika ne *) ze zokka ezikola.
Enyunzi esoka mu lunyiriri eteekwa okuba nga egguka ku fayiro eriko kiremya.
Enyunzi endala eziba ku lunyiriri olwo zibalibwa nga ezigguka ku mpapula ezikozesa fayiro eya kiremya eyo.',

# Metadata
'metadata'          => 'Ebikwata ku kifaananyi',
'metadata-help'     => "Ekyakozesebwa okutegeka fayiro eno esobole okugenda ku kompyuta, okugeza kamera oba sikaana, kyagiwandikamu ebigikwatako. Ebyawandikibwa ebyo biyinz'okuba nga tebikyamalayo fayiro ebigikwatako bw'ebanga okuva lweyasooka kutegebwa yakolebwako n'ate.",
'metadata-expand'   => 'Laba ebisingawo',
'metadata-collapse' => 'Kisako ebimu, wasigalewo ebisinga obukulu',
'metadata-fields'   => "Ebiddako bye ebikwata ku fayiro eno ebyagiwandikibwamu ekyagitegekera kompyuta ebijakusigala nga biragibwa.<br />
Ebirala biyinza butalabika okujjako ng'okiragidde.
* make
* model
* datetimeoriginal
* exposuretime
* fnumber
* isospeedratings
* focallength",

# External editor support
'edit-externally'      => 'Fayiro eno gikolereko mu pulogulamu endala',
'edit-externally-help' => '[http://www.mediawiki.org/wiki/Manual:External_editors Nyiga wano] okuyiga ebisingawo ku kukozesa pulogulamu endala okukola enkyukakyuka.',

# 'all' in various places, this might be different for inflected languages
'watchlistall2' => 'Zonna',
'namespacesall' => 'Gonna',
'monthsall'     => 'gyonna',

# action=purge
'confirm_purge_button' => 'Kale',

# Multipage image navigation
'imgmultigo' => 'Nona!',

# Table pager
'table_pager_next'         => 'Dda ku luddirira luno',
'table_pager_prev'         => 'Dda ku lukulembera luno',
'table_pager_first'        => 'Dda ku lupapula olubereberye',
'table_pager_last'         => 'Dda ku lupapula olusembayo',
'table_pager_limit'        => 'Ndaga ebintu $1 buli lupapula',
'table_pager_limit_submit' => 'Nona',

# Size units
'size-bytes'     => 'B $1',
'size-kilobytes' => 'KB $1',
'size-megabytes' => 'MB $1',
'size-gigabytes' => 'GB $1',

# Watchlist editing tools
'watchlisttools-view' => 'Kebera ebikyuse',
'watchlisttools-edit' => "Kola ku lukalala lwe'mpapula z'ogoberera",
'watchlisttools-raw'  => 'Wandika enkyukakyuka mu lukalala luno',

# Special:Version
'version-specialpages' => 'Empapula enjawule',

# Special:FileDuplicateSearch
'fileduplicatesearch-submit' => 'Noonya',

# Special:SpecialPages
'specialpages' => 'Empapula enjawule',

# Special:Tags
'tags-edit' => 'kyusa',

);
